Class: SparteraApiSdk::Alerts

Inherits:
ApiModelBase show all
Defined in:
lib/spartera_api_sdk/models/alerts.rb

Overview

A notification alert triggered when a subscribed asset is updated

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Alerts

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/spartera_api_sdk/models/alerts.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::Alerts` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::Alerts`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  end

  if attributes.key?(:'alert_id')
    self.alert_id = attributes[:'alert_id']
  end

  if attributes.key?(:'asset_id')
    self.asset_id = attributes[:'asset_id']
  else
    self.asset_id = nil
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'company_id')
    self.company_id = attributes[:'company_id']
  else
    self.company_id = nil
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  else
    self.is_active = nil
  end
end

Instance Attribute Details

#alert_idObject

Auto-generated unique identifier.



26
27
28
# File 'lib/spartera_api_sdk/models/alerts.rb', line 26

def alert_id
  @alert_id
end

#asset_idObject

References assets.asset_id — A published analytics asset — a calculation or visualization built on a data connection. See GET /assets for valid values. Required.



29
30
31
# File 'lib/spartera_api_sdk/models/alerts.rb', line 29

def asset_id
  @asset_id
end

#company_idObject

References companies.company_id — A Spartera seller or buyer company account. See GET /companies for valid values. Required.



35
36
37
# File 'lib/spartera_api_sdk/models/alerts.rb', line 35

def company_id
  @company_id
end

#date_createdObject

Optional.



20
21
22
# File 'lib/spartera_api_sdk/models/alerts.rb', line 20

def date_created
  @date_created
end

#is_activeObject

Whether this alert is currently active



38
39
40
# File 'lib/spartera_api_sdk/models/alerts.rb', line 38

def is_active
  @is_active
end

#last_updatedObject

Optional.



23
24
25
# File 'lib/spartera_api_sdk/models/alerts.rb', line 23

def last_updated
  @last_updated
end

#user_idObject

References users.user_id — An individual user account within a company. See GET /users for valid values. Optional.



32
33
34
# File 'lib/spartera_api_sdk/models/alerts.rb', line 32

def user_id
  @user_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/spartera_api_sdk/models/alerts.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/spartera_api_sdk/models/alerts.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/spartera_api_sdk/models/alerts.rb', line 41

def self.attribute_map
  {
    :'date_created' => :'date_created',
    :'last_updated' => :'last_updated',
    :'alert_id' => :'alert_id',
    :'asset_id' => :'asset_id',
    :'user_id' => :'user_id',
    :'company_id' => :'company_id',
    :'is_active' => :'is_active'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/spartera_api_sdk/models/alerts.rb', line 222

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/spartera_api_sdk/models/alerts.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
# File 'lib/spartera_api_sdk/models/alerts.rb', line 64

def self.openapi_types
  {
    :'date_created' => :'Time',
    :'last_updated' => :'Time',
    :'alert_id' => :'Integer',
    :'asset_id' => :'String',
    :'user_id' => :'String',
    :'company_id' => :'String',
    :'is_active' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



195
196
197
198
199
200
201
202
203
204
205
# File 'lib/spartera_api_sdk/models/alerts.rb', line 195

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      date_created == o.date_created &&
      last_updated == o.last_updated &&
      alert_id == o.alert_id &&
      asset_id == o.asset_id &&
      user_id == o.user_id &&
      company_id == o.company_id &&
      is_active == o.is_active
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


209
210
211
# File 'lib/spartera_api_sdk/models/alerts.rb', line 209

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



215
216
217
# File 'lib/spartera_api_sdk/models/alerts.rb', line 215

def hash
  [date_created, last_updated, alert_id, asset_id, user_id, company_id, is_active].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/spartera_api_sdk/models/alerts.rb', line 135

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @asset_id.nil?
    invalid_properties.push('invalid value for "asset_id", asset_id cannot be nil.')
  end

  if @company_id.nil?
    invalid_properties.push('invalid value for "company_id", company_id cannot be nil.')
  end

  if @is_active.nil?
    invalid_properties.push('invalid value for "is_active", is_active cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/spartera_api_sdk/models/alerts.rb', line 244

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
159
160
161
# File 'lib/spartera_api_sdk/models/alerts.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @asset_id.nil?
  return false if @company_id.nil?
  return false if @is_active.nil?
  true
end