Class: SparteraApiSdk::ApiKeys

Inherits:
ApiModelBase show all
Defined in:
lib/spartera_api_sdk/models/api_keys.rb

Overview

API keys for authenticating requests to the Spartera platform

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApiKeys

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::ApiKeys` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::ApiKeys`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  end

  if attributes.key?(:'api_key_id')
    self.api_key_id = attributes[:'api_key_id']
  else
    self.api_key_id = nil
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'company_id')
    self.company_id = attributes[:'company_id']
  else
    self.company_id = nil
  end

  if attributes.key?(:'role_id')
    self.role_id = attributes[:'role_id']
  else
    self.role_id = nil
  end

  if attributes.key?(:'key_type')
    self.key_type = attributes[:'key_type']
  else
    self.key_type = nil
  end

  if attributes.key?(:'is_system_generated')
    self.is_system_generated = attributes[:'is_system_generated']
  else
    self.is_system_generated = nil
  end

  if attributes.key?(:'mcp_deployment_id')
    self.mcp_deployment_id = attributes[:'mcp_deployment_id']
  end

  if attributes.key?(:'endpoint_id')
    self.endpoint_id = attributes[:'endpoint_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'expiration_date_utc')
    self.expiration_date_utc = attributes[:'expiration_date_utc']
  end
end

Instance Attribute Details

#api_key_idObject

Unique identifier.



26
27
28
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 26

def api_key_id
  @api_key_id
end

#company_idObject

Company this API key belongs to



32
33
34
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 32

def company_id
  @company_id
end

#date_createdObject

Optional.



20
21
22
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 20

def date_created
  @date_created
end

#endpoint_idObject

Endpoint this key is tied to (NULL for analytics/mcp keys)



47
48
49
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 47

def endpoint_id
  @endpoint_id
end

#expiration_date_utcObject

When this API key expires (NULL = never expires)



53
54
55
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 53

def expiration_date_utc
  @expiration_date_utc
end

#is_system_generatedObject

True if key was auto-generated for MCP deployment



41
42
43
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 41

def is_system_generated
  @is_system_generated
end

#key_typeObject

Type of API key (analytics, mcp, or endpoint)



38
39
40
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 38

def key_type
  @key_type
end

#last_updatedObject

Optional.



23
24
25
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 23

def last_updated
  @last_updated
end

#mcp_deployment_idObject

MCP deployment this key is tied to (NULL for analytics/endpoint keys)



44
45
46
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 44

def mcp_deployment_id
  @mcp_deployment_id
end

#nameObject

Human-readable name for this API key



50
51
52
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 50

def name
  @name
end

#role_idObject

Role/permission level for this API key



35
36
37
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 35

def role_id
  @role_id
end

#user_idObject

User who owns this API key



29
30
31
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 29

def user_id
  @user_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 56

def self.attribute_map
  {
    :'date_created' => :'date_created',
    :'last_updated' => :'last_updated',
    :'api_key_id' => :'api_key_id',
    :'user_id' => :'user_id',
    :'company_id' => :'company_id',
    :'role_id' => :'role_id',
    :'key_type' => :'key_type',
    :'is_system_generated' => :'is_system_generated',
    :'mcp_deployment_id' => :'mcp_deployment_id',
    :'endpoint_id' => :'endpoint_id',
    :'name' => :'name',
    :'expiration_date_utc' => :'expiration_date_utc'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 306

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 84

def self.openapi_types
  {
    :'date_created' => :'Time',
    :'last_updated' => :'Time',
    :'api_key_id' => :'Integer',
    :'user_id' => :'String',
    :'company_id' => :'String',
    :'role_id' => :'Integer',
    :'key_type' => :'String',
    :'is_system_generated' => :'Boolean',
    :'mcp_deployment_id' => :'String',
    :'endpoint_id' => :'String',
    :'name' => :'String',
    :'expiration_date_utc' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 274

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      date_created == o.date_created &&
      last_updated == o.last_updated &&
      api_key_id == o.api_key_id &&
      user_id == o.user_id &&
      company_id == o.company_id &&
      role_id == o.role_id &&
      key_type == o.key_type &&
      is_system_generated == o.is_system_generated &&
      mcp_deployment_id == o.mcp_deployment_id &&
      endpoint_id == o.endpoint_id &&
      name == o.name &&
      expiration_date_utc == o.expiration_date_utc
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


293
294
295
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 293

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



299
300
301
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 299

def hash
  [date_created, last_updated, api_key_id, user_id, company_id, role_id, key_type, is_system_generated, mcp_deployment_id, endpoint_id, name, expiration_date_utc].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 184

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @api_key_id.nil?
    invalid_properties.push('invalid value for "api_key_id", api_key_id cannot be nil.')
  end

  if @company_id.nil?
    invalid_properties.push('invalid value for "company_id", company_id cannot be nil.')
  end

  if @role_id.nil?
    invalid_properties.push('invalid value for "role_id", role_id cannot be nil.')
  end

  if @key_type.nil?
    invalid_properties.push('invalid value for "key_type", key_type cannot be nil.')
  end

  if @is_system_generated.nil?
    invalid_properties.push('invalid value for "is_system_generated", is_system_generated cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 328

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



212
213
214
215
216
217
218
219
220
# File 'lib/spartera_api_sdk/models/api_keys.rb', line 212

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @api_key_id.nil?
  return false if @company_id.nil?
  return false if @role_id.nil?
  return false if @key_type.nil?
  return false if @is_system_generated.nil?
  true
end