Class: SparteraApiSdk::ApiKeysInput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SparteraApiSdk::ApiKeysInput
- Defined in:
- lib/spartera_api_sdk/models/api_keys_input.rb
Overview
Input schema for creating ApiKey
Instance Attribute Summary collapse
-
#company_id ⇒ Object
Company this API key belongs to.
-
#endpoint_id ⇒ Object
Endpoint this key is tied to (NULL for analytics/mcp keys).
-
#expiration_date_utc ⇒ Object
When this API key expires (NULL = never expires).
-
#is_system_generated ⇒ Object
True if key was auto-generated for MCP deployment.
-
#key_type ⇒ Object
Type of API key (analytics, mcp, or endpoint).
-
#mcp_deployment_id ⇒ Object
MCP deployment this key is tied to (NULL for analytics/endpoint keys).
-
#name ⇒ Object
Human-readable name for this API key.
-
#role_id ⇒ Object
Role/permission level for this API key.
-
#user_id ⇒ Object
User who owns this API key.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiKeysInput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApiKeysInput
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::ApiKeysInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::ApiKeysInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'company_id') self.company_id = attributes[:'company_id'] else self.company_id = nil end if attributes.key?(:'role_id') self.role_id = attributes[:'role_id'] else self.role_id = nil end if attributes.key?(:'key_type') self.key_type = attributes[:'key_type'] end if attributes.key?(:'is_system_generated') self.is_system_generated = attributes[:'is_system_generated'] end if attributes.key?(:'mcp_deployment_id') self.mcp_deployment_id = attributes[:'mcp_deployment_id'] end if attributes.key?(:'endpoint_id') self.endpoint_id = attributes[:'endpoint_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'expiration_date_utc') self.expiration_date_utc = attributes[:'expiration_date_utc'] end end |
Instance Attribute Details
#company_id ⇒ Object
Company this API key belongs to
23 24 25 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 23 def company_id @company_id end |
#endpoint_id ⇒ Object
Endpoint this key is tied to (NULL for analytics/mcp keys)
38 39 40 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 38 def endpoint_id @endpoint_id end |
#expiration_date_utc ⇒ Object
When this API key expires (NULL = never expires)
44 45 46 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 44 def expiration_date_utc @expiration_date_utc end |
#is_system_generated ⇒ Object
True if key was auto-generated for MCP deployment
32 33 34 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 32 def is_system_generated @is_system_generated end |
#key_type ⇒ Object
Type of API key (analytics, mcp, or endpoint)
29 30 31 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 29 def key_type @key_type end |
#mcp_deployment_id ⇒ Object
MCP deployment this key is tied to (NULL for analytics/endpoint keys)
35 36 37 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 35 def mcp_deployment_id @mcp_deployment_id end |
#name ⇒ Object
Human-readable name for this API key
41 42 43 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 41 def name @name end |
#role_id ⇒ Object
Role/permission level for this API key
26 27 28 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 26 def role_id @role_id end |
#user_id ⇒ Object
User who owns this API key
20 21 22 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 20 def user_id @user_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 47 def self.attribute_map { :'user_id' => :'user_id', :'company_id' => :'company_id', :'role_id' => :'role_id', :'key_type' => :'key_type', :'is_system_generated' => :'is_system_generated', :'mcp_deployment_id' => :'mcp_deployment_id', :'endpoint_id' => :'endpoint_id', :'name' => :'name', :'expiration_date_utc' => :'expiration_date_utc' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 225 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 72 def self.openapi_types { :'user_id' => :'String', :'company_id' => :'String', :'role_id' => :'Integer', :'key_type' => :'String', :'is_system_generated' => :'Boolean', :'mcp_deployment_id' => :'String', :'endpoint_id' => :'String', :'name' => :'String', :'expiration_date_utc' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 196 def ==(o) return true if self.equal?(o) self.class == o.class && user_id == o.user_id && company_id == o.company_id && role_id == o.role_id && key_type == o.key_type && is_system_generated == o.is_system_generated && mcp_deployment_id == o.mcp_deployment_id && endpoint_id == o.endpoint_id && name == o.name && expiration_date_utc == o.expiration_date_utc end |
#eql?(o) ⇒ Boolean
212 213 214 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 212 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
218 219 220 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 218 def hash [user_id, company_id, role_id, key_type, is_system_generated, mcp_deployment_id, endpoint_id, name, expiration_date_utc].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @company_id.nil? invalid_properties.push('invalid value for "company_id", company_id cannot be nil.') end if @role_id.nil? invalid_properties.push('invalid value for "role_id", role_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 247 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
167 168 169 170 171 172 |
# File 'lib/spartera_api_sdk/models/api_keys_input.rb', line 167 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @company_id.nil? return false if @role_id.nil? true end |