Class: SparteraApiSdk::AssetUsecasesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/spartera_api_sdk/api/asset_usecases_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AssetUsecasesApi

Returns a new instance of AssetUsecasesApi.



19
20
21
# File 'lib/spartera_api_sdk/api/asset_usecases_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/spartera_api_sdk/api/asset_usecases_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_asset_usecases_by_id(auc_id, opts = {}) ⇒ GetAssetUsecasesById200Response

Get single asset use case by ID

Parameters:

  • auc_id (String)

    Unique identifier for the Auc

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



26
27
28
29
# File 'lib/spartera_api_sdk/api/asset_usecases_api.rb', line 26

def get_asset_usecases_by_id(auc_id, opts = {})
  data, _status_code, _headers = get_asset_usecases_by_id_with_http_info(auc_id, opts)
  data
end

#get_asset_usecases_by_id_with_http_info(auc_id, opts = {}) ⇒ Array<(GetAssetUsecasesById200Response, Integer, Hash)>

Get single asset use case by ID

Parameters:

  • auc_id (String)

    Unique identifier for the Auc

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/spartera_api_sdk/api/asset_usecases_api.rb', line 35

def get_asset_usecases_by_id_with_http_info(auc_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AssetUsecasesApi.get_asset_usecases_by_id ...'
  end
  # verify the required parameter 'auc_id' is set
  if @api_client.config.client_side_validation && auc_id.nil?
    fail ArgumentError, "Missing the required parameter 'auc_id' when calling AssetUsecasesApi.get_asset_usecases_by_id"
  end
  if @api_client.config.client_side_validation && auc_id.to_s.length > 255
    fail ArgumentError, 'invalid value for "auc_id" when calling AssetUsecasesApi.get_asset_usecases_by_id, the character length must be smaller than or equal to 255.'
  end

  if @api_client.config.client_side_validation && auc_id.to_s.length < 1
    fail ArgumentError, 'invalid value for "auc_id" when calling AssetUsecasesApi.get_asset_usecases_by_id, the character length must be greater than or equal to 1.'
  end

  pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/)
  if @api_client.config.client_side_validation && auc_id !~ pattern
    fail ArgumentError, "invalid value for 'auc_id' when calling AssetUsecasesApi.get_asset_usecases_by_id, must conform to the pattern #{pattern}."
  end

  # resource path
  local_var_path = '/asset_usecases/{auc_id}'.sub('{' + 'auc_id' + '}', CGI.escape(auc_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetAssetUsecasesById200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"AssetUsecasesApi.get_asset_usecases_by_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AssetUsecasesApi#get_asset_usecases_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_asset_usecases(opts = {}) ⇒ ListAssetUsecases200Response

Get a list of all asset use cases

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Page number for pagination (default to 1)

  • :limit (Integer)

    Number of items per page (default to 20)

  • :sort_by (String)

    Field to sort by

  • :sort_order (String)

    Sort order (ascending or descending) (default to ‘desc’)

  • :search (String)

    Search term to filter results

Returns:



104
105
106
107
# File 'lib/spartera_api_sdk/api/asset_usecases_api.rb', line 104

def list_asset_usecases(opts = {})
  data, _status_code, _headers = list_asset_usecases_with_http_info(opts)
  data
end

#list_asset_usecases_with_http_info(opts = {}) ⇒ Array<(ListAssetUsecases200Response, Integer, Hash)>

Get a list of all asset use cases

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Page number for pagination (default to 1)

  • :limit (Integer)

    Number of items per page (default to 20)

  • :sort_by (String)

    Field to sort by

  • :sort_order (String)

    Sort order (ascending or descending) (default to ‘desc’)

  • :search (String)

    Search term to filter results

Returns:



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/spartera_api_sdk/api/asset_usecases_api.rb', line 117

def list_asset_usecases_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AssetUsecasesApi.list_asset_usecases ...'
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling AssetUsecasesApi.list_asset_usecases, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AssetUsecasesApi.list_asset_usecases, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AssetUsecasesApi.list_asset_usecases, must be greater than or equal to 1.'
  end

  allowable_values = ["asc", "desc"]
  if @api_client.config.client_side_validation && opts[:'sort_order'] && !allowable_values.include?(opts[:'sort_order'])
    fail ArgumentError, "invalid value for \"sort_order\", must be one of #{allowable_values}"
  end
  if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length > 255
    fail ArgumentError, 'invalid value for "opts[:"search"]" when calling AssetUsecasesApi.list_asset_usecases, the character length must be smaller than or equal to 255.'
  end

  if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length < 1
    fail ArgumentError, 'invalid value for "opts[:"search"]" when calling AssetUsecasesApi.list_asset_usecases, the character length must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/asset_usecases'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil?
  query_params[:'sort_order'] = opts[:'sort_order'] if !opts[:'sort_order'].nil?
  query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListAssetUsecases200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"AssetUsecasesApi.list_asset_usecases",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AssetUsecasesApi#list_asset_usecases\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end