Class: SparteraApiSdk::CloudProvidersApi
- Inherits:
-
Object
- Object
- SparteraApiSdk::CloudProvidersApi
- Defined in:
- lib/spartera_api_sdk/api/cloud_providers_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_cloud_providers_by_id(provider_id, opts = {}) ⇒ GetCloudProvidersById200Response
Get single cloud provider by ID.
-
#get_cloud_providers_by_id_with_http_info(provider_id, opts = {}) ⇒ Array<(GetCloudProvidersById200Response, Integer, Hash)>
Get single cloud provider by ID.
-
#initialize(api_client = ApiClient.default) ⇒ CloudProvidersApi
constructor
A new instance of CloudProvidersApi.
-
#list_cloud_providers(opts = {}) ⇒ ListCloudProviders200Response
Get a list of all cloud providers.
-
#list_cloud_providers_with_http_info(opts = {}) ⇒ Array<(ListCloudProviders200Response, Integer, Hash)>
Get a list of all cloud providers.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CloudProvidersApi
Returns a new instance of CloudProvidersApi.
19 20 21 |
# File 'lib/spartera_api_sdk/api/cloud_providers_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/spartera_api_sdk/api/cloud_providers_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_cloud_providers_by_id(provider_id, opts = {}) ⇒ GetCloudProvidersById200Response
Get single cloud provider by ID
26 27 28 29 |
# File 'lib/spartera_api_sdk/api/cloud_providers_api.rb', line 26 def get_cloud_providers_by_id(provider_id, opts = {}) data, _status_code, _headers = get_cloud_providers_by_id_with_http_info(provider_id, opts) data end |
#get_cloud_providers_by_id_with_http_info(provider_id, opts = {}) ⇒ Array<(GetCloudProvidersById200Response, Integer, Hash)>
Get single cloud provider by ID
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/spartera_api_sdk/api/cloud_providers_api.rb', line 35 def get_cloud_providers_by_id_with_http_info(provider_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudProvidersApi.get_cloud_providers_by_id ...' end # verify the required parameter 'provider_id' is set if @api_client.config.client_side_validation && provider_id.nil? fail ArgumentError, "Missing the required parameter 'provider_id' when calling CloudProvidersApi.get_cloud_providers_by_id" end if @api_client.config.client_side_validation && provider_id.to_s.length > 255 fail ArgumentError, 'invalid value for "provider_id" when calling CloudProvidersApi.get_cloud_providers_by_id, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && provider_id.to_s.length < 1 fail ArgumentError, 'invalid value for "provider_id" when calling CloudProvidersApi.get_cloud_providers_by_id, the character length must be greater than or equal to 1.' end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if @api_client.config.client_side_validation && provider_id !~ pattern fail ArgumentError, "invalid value for 'provider_id' when calling CloudProvidersApi.get_cloud_providers_by_id, must conform to the pattern #{pattern}." end # resource path local_var_path = '/cloud-providers/{provider_id}'.sub('{' + 'provider_id' + '}', CGI.escape(provider_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetCloudProvidersById200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CloudProvidersApi.get_cloud_providers_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudProvidersApi#get_cloud_providers_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_cloud_providers(opts = {}) ⇒ ListCloudProviders200Response
Get a list of all cloud providers
104 105 106 107 |
# File 'lib/spartera_api_sdk/api/cloud_providers_api.rb', line 104 def list_cloud_providers(opts = {}) data, _status_code, _headers = list_cloud_providers_with_http_info(opts) data end |
#list_cloud_providers_with_http_info(opts = {}) ⇒ Array<(ListCloudProviders200Response, Integer, Hash)>
Get a list of all cloud providers
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/spartera_api_sdk/api/cloud_providers_api.rb', line 117 def list_cloud_providers_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CloudProvidersApi.list_cloud_providers ...' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling CloudProvidersApi.list_cloud_providers, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudProvidersApi.list_cloud_providers, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CloudProvidersApi.list_cloud_providers, must be greater than or equal to 1.' end allowable_values = ["asc", "desc"] if @api_client.config.client_side_validation && opts[:'sort_order'] && !allowable_values.include?(opts[:'sort_order']) fail ArgumentError, "invalid value for \"sort_order\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length > 255 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CloudProvidersApi.list_cloud_providers, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CloudProvidersApi.list_cloud_providers, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/cloud-providers' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? query_params[:'sort_order'] = opts[:'sort_order'] if !opts[:'sort_order'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListCloudProviders200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CloudProvidersApi.list_cloud_providers", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CloudProvidersApi#list_cloud_providers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |