Class: SparteraApiSdk::CompaniesApi
- Inherits:
-
Object
- Object
- SparteraApiSdk::CompaniesApi
- Defined in:
- lib/spartera_api_sdk/api/companies_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_companies_by_id(company_id, opts = {}) ⇒ GetCompaniesById200Response
Get details of the requestor’s own company.
-
#get_companies_by_id_with_http_info(company_id, opts = {}) ⇒ Array<(GetCompaniesById200Response, Integer, Hash)>
Get details of the requestor's own company.
-
#initialize(api_client = ApiClient.default) ⇒ CompaniesApi
constructor
A new instance of CompaniesApi.
-
#list_companies(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get the total number of requests allocated in the company’s current subscription plan.
-
#list_companies_analytics_assets(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get asset performance analytics.
-
#list_companies_analytics_assets_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get asset performance analytics.
-
#list_companies_analytics_customers(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get customer analytics including growth and segmentation.
-
#list_companies_analytics_customers_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get customer analytics including growth and segmentation.
-
#list_companies_analytics_dashboard(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get comprehensive dashboard analytics for seller dashboard.
-
#list_companies_analytics_dashboard_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get comprehensive dashboard analytics for seller dashboard.
-
#list_companies_analytics_metrics(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get summary metrics (counts only).
-
#list_companies_analytics_metrics_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get summary metrics (counts only).
-
#list_companies_analytics_sales(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get sales over time analytics.
-
#list_companies_analytics_sales_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get sales over time analytics.
-
#list_companies_objects(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get all objects (connections, assets) of a single company.
-
#list_companies_objects_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get all objects (connections, assets) of a single company.
-
#list_companies_requests_usage(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get company request usage data for a specific month.
-
#list_companies_requests_usage_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get company request usage data for a specific month.
-
#list_companies_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get the total number of requests allocated in the company's current subscription plan.
-
#update_companies(company_id, companies_update, opts = {}) ⇒ UpdateCompanies200Response
Update an existing company by ID.
-
#update_companies_with_http_info(company_id, companies_update, opts = {}) ⇒ Array<(UpdateCompanies200Response, Integer, Hash)>
Update an existing company by ID.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CompaniesApi
Returns a new instance of CompaniesApi.
19 20 21 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_companies_by_id(company_id, opts = {}) ⇒ GetCompaniesById200Response
Get details of the requestor’s own company
26 27 28 29 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 26 def get_companies_by_id(company_id, opts = {}) data, _status_code, _headers = get_companies_by_id_with_http_info(company_id, opts) data end |
#get_companies_by_id_with_http_info(company_id, opts = {}) ⇒ Array<(GetCompaniesById200Response, Integer, Hash)>
Get details of the requestor's own company
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 35 def get_companies_by_id_with_http_info(company_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.get_companies_by_id ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling CompaniesApi.get_companies_by_id" end if @api_client.config.client_side_validation && company_id.to_s.length > 255 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.get_companies_by_id, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && company_id.to_s.length < 1 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.get_companies_by_id, the character length must be greater than or equal to 1.' end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if @api_client.config.client_side_validation && company_id !~ pattern fail ArgumentError, "invalid value for 'company_id' when calling CompaniesApi.get_companies_by_id, must conform to the pattern #{pattern}." end # resource path local_var_path = '/companies/{company_id}'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetCompaniesById200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CompaniesApi.get_companies_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#get_companies_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_companies(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get the total number of requests allocated in the company’s current subscription plan.
105 106 107 108 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 105 def list_companies(company_id, opts = {}) data, _status_code, _headers = list_companies_with_http_info(company_id, opts) data end |
#list_companies_analytics_assets(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get asset performance analytics. Query params: start_date, end_date, limit, sort_by, include
218 219 220 221 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 218 def list_companies_analytics_assets(company_id, opts = {}) data, _status_code, _headers = list_companies_analytics_assets_with_http_info(company_id, opts) data end |
#list_companies_analytics_assets_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get asset performance analytics. Query params: start_date, end_date, limit, sort_by, include
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 232 def list_companies_analytics_assets_with_http_info(company_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.list_companies_analytics_assets ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling CompaniesApi.list_companies_analytics_assets" end if @api_client.config.client_side_validation && company_id.to_s.length > 255 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies_analytics_assets, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && company_id.to_s.length < 1 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies_analytics_assets, the character length must be greater than or equal to 1.' end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if @api_client.config.client_side_validation && company_id !~ pattern fail ArgumentError, "invalid value for 'company_id' when calling CompaniesApi.list_companies_analytics_assets, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling CompaniesApi.list_companies_analytics_assets, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies_analytics_assets, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies_analytics_assets, must be greater than or equal to 1.' end allowable_values = ["asc", "desc"] if @api_client.config.client_side_validation && opts[:'sort_order'] && !allowable_values.include?(opts[:'sort_order']) fail ArgumentError, "invalid value for \"sort_order\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length > 255 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies_analytics_assets, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies_analytics_assets, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/companies/{company_id}/analytics/assets'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? query_params[:'sort_order'] = opts[:'sort_order'] if !opts[:'sort_order'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListCompaniesAnalyticsAssets200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CompaniesApi.list_companies_analytics_assets", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#list_companies_analytics_assets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_companies_analytics_customers(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get customer analytics including growth and segmentation. Query params: start_date, end_date, group_by, segment_by
331 332 333 334 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 331 def list_companies_analytics_customers(company_id, opts = {}) data, _status_code, _headers = list_companies_analytics_customers_with_http_info(company_id, opts) data end |
#list_companies_analytics_customers_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get customer analytics including growth and segmentation. Query params: start_date, end_date, group_by, segment_by
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 345 def list_companies_analytics_customers_with_http_info(company_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.list_companies_analytics_customers ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling CompaniesApi.list_companies_analytics_customers" end if @api_client.config.client_side_validation && company_id.to_s.length > 255 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies_analytics_customers, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && company_id.to_s.length < 1 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies_analytics_customers, the character length must be greater than or equal to 1.' end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if @api_client.config.client_side_validation && company_id !~ pattern fail ArgumentError, "invalid value for 'company_id' when calling CompaniesApi.list_companies_analytics_customers, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling CompaniesApi.list_companies_analytics_customers, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies_analytics_customers, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies_analytics_customers, must be greater than or equal to 1.' end allowable_values = ["asc", "desc"] if @api_client.config.client_side_validation && opts[:'sort_order'] && !allowable_values.include?(opts[:'sort_order']) fail ArgumentError, "invalid value for \"sort_order\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length > 255 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies_analytics_customers, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies_analytics_customers, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/companies/{company_id}/analytics/customers'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? query_params[:'sort_order'] = opts[:'sort_order'] if !opts[:'sort_order'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListCompaniesAnalyticsAssets200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CompaniesApi.list_companies_analytics_customers", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#list_companies_analytics_customers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_companies_analytics_dashboard(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get comprehensive dashboard analytics for seller dashboard. Query params: start_date, end_date, period (day/week/month/quarter)
444 445 446 447 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 444 def list_companies_analytics_dashboard(company_id, opts = {}) data, _status_code, _headers = list_companies_analytics_dashboard_with_http_info(company_id, opts) data end |
#list_companies_analytics_dashboard_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get comprehensive dashboard analytics for seller dashboard. Query params: start_date, end_date, period (day/week/month/quarter)
458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 458 def list_companies_analytics_dashboard_with_http_info(company_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.list_companies_analytics_dashboard ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling CompaniesApi.list_companies_analytics_dashboard" end if @api_client.config.client_side_validation && company_id.to_s.length > 255 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies_analytics_dashboard, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && company_id.to_s.length < 1 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies_analytics_dashboard, the character length must be greater than or equal to 1.' end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if @api_client.config.client_side_validation && company_id !~ pattern fail ArgumentError, "invalid value for 'company_id' when calling CompaniesApi.list_companies_analytics_dashboard, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling CompaniesApi.list_companies_analytics_dashboard, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies_analytics_dashboard, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies_analytics_dashboard, must be greater than or equal to 1.' end allowable_values = ["asc", "desc"] if @api_client.config.client_side_validation && opts[:'sort_order'] && !allowable_values.include?(opts[:'sort_order']) fail ArgumentError, "invalid value for \"sort_order\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length > 255 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies_analytics_dashboard, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies_analytics_dashboard, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/companies/{company_id}/analytics/dashboard'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? query_params[:'sort_order'] = opts[:'sort_order'] if !opts[:'sort_order'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListCompaniesAnalyticsAssets200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CompaniesApi.list_companies_analytics_dashboard", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#list_companies_analytics_dashboard\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_companies_analytics_metrics(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get summary metrics (counts only). No date params needed — returns all-time totals. Performance: < 0.1s
557 558 559 560 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 557 def list_companies_analytics_metrics(company_id, opts = {}) data, _status_code, _headers = list_companies_analytics_metrics_with_http_info(company_id, opts) data end |
#list_companies_analytics_metrics_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get summary metrics (counts only). No date params needed — returns all-time totals. Performance: < 0.1s
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 571 def list_companies_analytics_metrics_with_http_info(company_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.list_companies_analytics_metrics ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling CompaniesApi.list_companies_analytics_metrics" end if @api_client.config.client_side_validation && company_id.to_s.length > 255 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies_analytics_metrics, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && company_id.to_s.length < 1 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies_analytics_metrics, the character length must be greater than or equal to 1.' end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if @api_client.config.client_side_validation && company_id !~ pattern fail ArgumentError, "invalid value for 'company_id' when calling CompaniesApi.list_companies_analytics_metrics, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling CompaniesApi.list_companies_analytics_metrics, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies_analytics_metrics, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies_analytics_metrics, must be greater than or equal to 1.' end allowable_values = ["asc", "desc"] if @api_client.config.client_side_validation && opts[:'sort_order'] && !allowable_values.include?(opts[:'sort_order']) fail ArgumentError, "invalid value for \"sort_order\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length > 255 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies_analytics_metrics, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies_analytics_metrics, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/companies/{company_id}/analytics/metrics'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? query_params[:'sort_order'] = opts[:'sort_order'] if !opts[:'sort_order'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListCompaniesAnalyticsAssets200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CompaniesApi.list_companies_analytics_metrics", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#list_companies_analytics_metrics\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_companies_analytics_sales(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get sales over time analytics. Query params: start_date, end_date, group_by (day/week/month/quarter), metrics
670 671 672 673 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 670 def list_companies_analytics_sales(company_id, opts = {}) data, _status_code, _headers = list_companies_analytics_sales_with_http_info(company_id, opts) data end |
#list_companies_analytics_sales_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get sales over time analytics. Query params: start_date, end_date, group_by (day/week/month/quarter), metrics
684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 684 def list_companies_analytics_sales_with_http_info(company_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.list_companies_analytics_sales ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling CompaniesApi.list_companies_analytics_sales" end if @api_client.config.client_side_validation && company_id.to_s.length > 255 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies_analytics_sales, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && company_id.to_s.length < 1 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies_analytics_sales, the character length must be greater than or equal to 1.' end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if @api_client.config.client_side_validation && company_id !~ pattern fail ArgumentError, "invalid value for 'company_id' when calling CompaniesApi.list_companies_analytics_sales, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling CompaniesApi.list_companies_analytics_sales, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies_analytics_sales, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies_analytics_sales, must be greater than or equal to 1.' end allowable_values = ["asc", "desc"] if @api_client.config.client_side_validation && opts[:'sort_order'] && !allowable_values.include?(opts[:'sort_order']) fail ArgumentError, "invalid value for \"sort_order\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length > 255 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies_analytics_sales, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies_analytics_sales, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/companies/{company_id}/analytics/sales'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? query_params[:'sort_order'] = opts[:'sort_order'] if !opts[:'sort_order'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListCompaniesAnalyticsAssets200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CompaniesApi.list_companies_analytics_sales", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#list_companies_analytics_sales\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_companies_objects(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get all objects (connections, assets) of a single company
783 784 785 786 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 783 def list_companies_objects(company_id, opts = {}) data, _status_code, _headers = list_companies_objects_with_http_info(company_id, opts) data end |
#list_companies_objects_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get all objects (connections, assets) of a single company
797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 797 def list_companies_objects_with_http_info(company_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.list_companies_objects ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling CompaniesApi.list_companies_objects" end if @api_client.config.client_side_validation && company_id.to_s.length > 255 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies_objects, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && company_id.to_s.length < 1 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies_objects, the character length must be greater than or equal to 1.' end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if @api_client.config.client_side_validation && company_id !~ pattern fail ArgumentError, "invalid value for 'company_id' when calling CompaniesApi.list_companies_objects, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling CompaniesApi.list_companies_objects, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies_objects, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies_objects, must be greater than or equal to 1.' end allowable_values = ["asc", "desc"] if @api_client.config.client_side_validation && opts[:'sort_order'] && !allowable_values.include?(opts[:'sort_order']) fail ArgumentError, "invalid value for \"sort_order\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length > 255 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies_objects, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies_objects, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/companies/{company_id}/objects'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? query_params[:'sort_order'] = opts[:'sort_order'] if !opts[:'sort_order'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListCompaniesAnalyticsAssets200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CompaniesApi.list_companies_objects", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#list_companies_objects\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_companies_requests_usage(company_id, opts = {}) ⇒ ListCompaniesAnalyticsAssets200Response
Get company request usage data for a specific month.
896 897 898 899 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 896 def list_companies_requests_usage(company_id, opts = {}) data, _status_code, _headers = list_companies_requests_usage_with_http_info(company_id, opts) data end |
#list_companies_requests_usage_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get company request usage data for a specific month.
910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 910 def list_companies_requests_usage_with_http_info(company_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.list_companies_requests_usage ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling CompaniesApi.list_companies_requests_usage" end if @api_client.config.client_side_validation && company_id.to_s.length > 255 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies_requests_usage, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && company_id.to_s.length < 1 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies_requests_usage, the character length must be greater than or equal to 1.' end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if @api_client.config.client_side_validation && company_id !~ pattern fail ArgumentError, "invalid value for 'company_id' when calling CompaniesApi.list_companies_requests_usage, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling CompaniesApi.list_companies_requests_usage, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies_requests_usage, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies_requests_usage, must be greater than or equal to 1.' end allowable_values = ["asc", "desc"] if @api_client.config.client_side_validation && opts[:'sort_order'] && !allowable_values.include?(opts[:'sort_order']) fail ArgumentError, "invalid value for \"sort_order\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length > 255 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies_requests_usage, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies_requests_usage, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/companies/{company_id}/requests/usage'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? query_params[:'sort_order'] = opts[:'sort_order'] if !opts[:'sort_order'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListCompaniesAnalyticsAssets200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CompaniesApi.list_companies_requests_usage", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#list_companies_requests_usage\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_companies_with_http_info(company_id, opts = {}) ⇒ Array<(ListCompaniesAnalyticsAssets200Response, Integer, Hash)>
Get the total number of requests allocated in the company's current subscription plan.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 119 def list_companies_with_http_info(company_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.list_companies ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling CompaniesApi.list_companies" end if @api_client.config.client_side_validation && company_id.to_s.length > 255 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && company_id.to_s.length < 1 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.list_companies, the character length must be greater than or equal to 1.' end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if @api_client.config.client_side_validation && company_id !~ pattern fail ArgumentError, "invalid value for 'company_id' when calling CompaniesApi.list_companies, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling CompaniesApi.list_companies, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CompaniesApi.list_companies, must be greater than or equal to 1.' end allowable_values = ["asc", "desc"] if @api_client.config.client_side_validation && opts[:'sort_order'] && !allowable_values.include?(opts[:'sort_order']) fail ArgumentError, "invalid value for \"sort_order\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length > 255 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling CompaniesApi.list_companies, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/companies/{company_id}/requests/plan'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? query_params[:'sort_order'] = opts[:'sort_order'] if !opts[:'sort_order'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListCompaniesAnalyticsAssets200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CompaniesApi.list_companies", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#list_companies\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_companies(company_id, companies_update, opts = {}) ⇒ UpdateCompanies200Response
Update an existing company by ID
1005 1006 1007 1008 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 1005 def update_companies(company_id, companies_update, opts = {}) data, _status_code, _headers = update_companies_with_http_info(company_id, companies_update, opts) data end |
#update_companies_with_http_info(company_id, companies_update, opts = {}) ⇒ Array<(UpdateCompanies200Response, Integer, Hash)>
Update an existing company by ID
1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 |
# File 'lib/spartera_api_sdk/api/companies_api.rb', line 1015 def update_companies_with_http_info(company_id, companies_update, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CompaniesApi.update_companies ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling CompaniesApi.update_companies" end if @api_client.config.client_side_validation && company_id.to_s.length > 255 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.update_companies, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && company_id.to_s.length < 1 fail ArgumentError, 'invalid value for "company_id" when calling CompaniesApi.update_companies, the character length must be greater than or equal to 1.' end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if @api_client.config.client_side_validation && company_id !~ pattern fail ArgumentError, "invalid value for 'company_id' when calling CompaniesApi.update_companies, must conform to the pattern #{pattern}." end # verify the required parameter 'companies_update' is set if @api_client.config.client_side_validation && companies_update.nil? fail ArgumentError, "Missing the required parameter 'companies_update' when calling CompaniesApi.update_companies" end # resource path local_var_path = '/companies/{company_id}'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(companies_update) # return_type return_type = opts[:debug_return_type] || 'UpdateCompanies200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CompaniesApi.update_companies", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CompaniesApi#update_companies\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |