Class: SparteraApiSdk::CompaniesUpdate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SparteraApiSdk::CompaniesUpdate
- Defined in:
- lib/spartera_api_sdk/models/companies_update.rb
Overview
Update schema for modifying Company
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#accepted_eula ⇒ Object
Optional.
-
#company_description ⇒ Object
Optional.
-
#company_domain ⇒ Object
Required.
-
#company_handle ⇒ Object
Required.
-
#company_name ⇒ Object
Optional.
-
#country_id ⇒ Object
References countries.country_id — List of countries of the world.
-
#credits_balance ⇒ Object
Current balance of credits for this company (buyer).
-
#industry_id ⇒ Object
References industries.industry_id — Available industry categories for asset classification.
-
#partnership_type ⇒ Object
Partnership type: SELF_MANAGED, CUSTODIAN, or null.
-
#stripe_account_id ⇒ Object
Stripe Connect account ID for marketplace sellers.
-
#stripe_account_status ⇒ Object
Status of the Stripe account (verified, pending, etc.).
-
#vendor_share_percent ⇒ Object
Negotiated vendor revenue share (e.g. 0.85 = 85%).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CompaniesUpdate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CompaniesUpdate
Initializes the object
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 131 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::CompaniesUpdate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::CompaniesUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'industry_id') self.industry_id = attributes[:'industry_id'] end if attributes.key?(:'country_id') self.country_id = attributes[:'country_id'] end if attributes.key?(:'company_name') self.company_name = attributes[:'company_name'] end if attributes.key?(:'company_description') self.company_description = attributes[:'company_description'] end if attributes.key?(:'company_handle') self.company_handle = attributes[:'company_handle'] end if attributes.key?(:'company_domain') self.company_domain = attributes[:'company_domain'] end if attributes.key?(:'credits_balance') self.credits_balance = attributes[:'credits_balance'] end if attributes.key?(:'accepted_eula') self.accepted_eula = attributes[:'accepted_eula'] end if attributes.key?(:'stripe_account_id') self.stripe_account_id = attributes[:'stripe_account_id'] end if attributes.key?(:'stripe_account_status') self.stripe_account_status = attributes[:'stripe_account_status'] end if attributes.key?(:'vendor_share_percent') self.vendor_share_percent = attributes[:'vendor_share_percent'] end if attributes.key?(:'partnership_type') self.partnership_type = attributes[:'partnership_type'] end end |
Instance Attribute Details
#accepted_eula ⇒ Object
Optional.
41 42 43 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 41 def accepted_eula @accepted_eula end |
#company_description ⇒ Object
Optional.
29 30 31 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 29 def company_description @company_description end |
#company_domain ⇒ Object
Required. Must be unique.
35 36 37 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 35 def company_domain @company_domain end |
#company_handle ⇒ Object
Required. Must be unique.
32 33 34 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 32 def company_handle @company_handle end |
#company_name ⇒ Object
Optional.
26 27 28 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 26 def company_name @company_name end |
#country_id ⇒ Object
References countries.country_id — List of countries of the world. See GET /countries for valid values. Optional.
23 24 25 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 23 def country_id @country_id end |
#credits_balance ⇒ Object
Current balance of credits for this company (buyer)
38 39 40 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 38 def credits_balance @credits_balance end |
#industry_id ⇒ Object
References industries.industry_id — Available industry categories for asset classification. Based on US NAISC codes.. See GET /industries for valid values. Optional.
20 21 22 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 20 def industry_id @industry_id end |
#partnership_type ⇒ Object
Partnership type: SELF_MANAGED, CUSTODIAN, or null
53 54 55 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 53 def partnership_type @partnership_type end |
#stripe_account_id ⇒ Object
Stripe Connect account ID for marketplace sellers
44 45 46 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 44 def stripe_account_id @stripe_account_id end |
#stripe_account_status ⇒ Object
Status of the Stripe account (verified, pending, etc.)
47 48 49 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 47 def stripe_account_status @stripe_account_status end |
#vendor_share_percent ⇒ Object
Negotiated vendor revenue share (e.g. 0.85 = 85%). NULL = system default 80%.
50 51 52 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 50 def vendor_share_percent @vendor_share_percent end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
96 97 98 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 96 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
101 102 103 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 101 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 78 def self.attribute_map { :'industry_id' => :'industry_id', :'country_id' => :'country_id', :'company_name' => :'company_name', :'company_description' => :'company_description', :'company_handle' => :'company_handle', :'company_domain' => :'company_domain', :'credits_balance' => :'credits_balance', :'accepted_eula' => :'accepted_eula', :'stripe_account_id' => :'stripe_account_id', :'stripe_account_status' => :'stripe_account_status', :'vendor_share_percent' => :'vendor_share_percent', :'partnership_type' => :'partnership_type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 255 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
124 125 126 127 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 124 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 106 def self.openapi_types { :'industry_id' => :'Integer', :'country_id' => :'Integer', :'company_name' => :'String', :'company_description' => :'String', :'company_handle' => :'String', :'company_domain' => :'String', :'credits_balance' => :'Integer', :'accepted_eula' => :'Boolean', :'stripe_account_id' => :'String', :'stripe_account_status' => :'String', :'vendor_share_percent' => :'Float', :'partnership_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 223 def ==(o) return true if self.equal?(o) self.class == o.class && industry_id == o.industry_id && country_id == o.country_id && company_name == o.company_name && company_description == o.company_description && company_handle == o.company_handle && company_domain == o.company_domain && credits_balance == o.credits_balance && accepted_eula == o.accepted_eula && stripe_account_id == o.stripe_account_id && stripe_account_status == o.stripe_account_status && vendor_share_percent == o.vendor_share_percent && partnership_type == o.partnership_type end |
#eql?(o) ⇒ Boolean
242 243 244 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 242 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 248 def hash [industry_id, country_id, company_name, company_description, company_handle, company_domain, credits_balance, accepted_eula, stripe_account_id, stripe_account_status, vendor_share_percent, partnership_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
196 197 198 199 200 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 196 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 277 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
204 205 206 207 208 209 |
# File 'lib/spartera_api_sdk/models/companies_update.rb', line 204 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' partnership_type_validator = EnumAttributeValidator.new('String', ["SELF_MANAGED", "CUSTODIAN"]) return false unless partnership_type_validator.valid?(@partnership_type) true end |