Class: SparteraApiSdk::EndpointsInput

Inherits:
ApiModelBase show all
Defined in:
lib/spartera_api_sdk/models/endpoints_input.rb

Overview

Input schema for creating Endpoint

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EndpointsInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 266

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::EndpointsInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::EndpointsInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'company_id')
    self.company_id = attributes[:'company_id']
  else
    self.company_id = nil
  end

  if attributes.key?(:'connection_id')
    self.connection_id = attributes[:'connection_id']
  else
    self.connection_id = nil
  end

  if attributes.key?(:'industry_id')
    self.industry_id = attributes[:'industry_id']
  end

  if attributes.key?(:'auc_id')
    self.auc_id = attributes[:'auc_id']
  end

  if attributes.key?(:'approval_status')
    self.approval_status = attributes[:'approval_status']
  end

  if attributes.key?(:'approved_by_user_id')
    self.approved_by_user_id = attributes[:'approved_by_user_id']
  end

  if attributes.key?(:'approved_at')
    self.approved_at = attributes[:'approved_at']
  end

  if attributes.key?(:'sell_in_marketplace')
    self.sell_in_marketplace = attributes[:'sell_in_marketplace']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'detailed_description')
    self.detailed_description = attributes[:'detailed_description']
  end

  if attributes.key?(:'top_questions')
    self.top_questions = attributes[:'top_questions']
  end

  if attributes.key?(:'source_schema_name')
    self.source_schema_name = attributes[:'source_schema_name']
  end

  if attributes.key?(:'source_table_name')
    self.source_table_name = attributes[:'source_table_name']
  end

  if attributes.key?(:'customer_name')
    self.customer_name = attributes[:'customer_name']
  end

  if attributes.key?(:'endpoint_schema')
    self.endpoint_schema = attributes[:'endpoint_schema']
  end

  if attributes.key?(:'rate_limit_number')
    self.rate_limit_number = attributes[:'rate_limit_number']
  end

  if attributes.key?(:'rate_limit_period')
    self.rate_limit_period = attributes[:'rate_limit_period']
  end

  if attributes.key?(:'rate_limit_granularity')
    self.rate_limit_granularity = attributes[:'rate_limit_granularity']
  end

  if attributes.key?(:'access_method')
    self.access_method = attributes[:'access_method']
  end

  if attributes.key?(:'access_whitelist')
    self.access_whitelist = attributes[:'access_whitelist']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'data_time_period_start')
    self.data_time_period_start = attributes[:'data_time_period_start']
  end

  if attributes.key?(:'data_time_period_end')
    self.data_time_period_end = attributes[:'data_time_period_end']
  end

  if attributes.key?(:'date_collection_start')
    self.date_collection_start = attributes[:'date_collection_start']
  end

  if attributes.key?(:'geographic_coverage_type')
    self.geographic_coverage_type = attributes[:'geographic_coverage_type']
  end

  if attributes.key?(:'geographic_coverage_details')
    self.geographic_coverage_details = attributes[:'geographic_coverage_details']
  end

  if attributes.key?(:'data_source_refresh_frequency')
    self.data_source_refresh_frequency = attributes[:'data_source_refresh_frequency']
  end

  if attributes.key?(:'tags')
    self.tags = attributes[:'tags']
  end

  if attributes.key?(:'last_accessed')
    self.last_accessed = attributes[:'last_accessed']
  end

  if attributes.key?(:'max_records_per_request')
    self.max_records_per_request = attributes[:'max_records_per_request']
  end

  if attributes.key?(:'export_enabled')
    self.export_enabled = attributes[:'export_enabled']
  end

  if attributes.key?(:'max_records_per_export')
    self.max_records_per_export = attributes[:'max_records_per_export']
  end

  if attributes.key?(:'sample_response')
    self.sample_response = attributes[:'sample_response']
  end

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  end
end

Instance Attribute Details

#access_methodObject

Access control method (OPEN, API_KEY, IP, EMAIL, DOMAIN)



89
90
91
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 89

def access_method
  @access_method
end

#access_whitelistObject

List of allowed IPs, emails, or domains based on access_method. Format: ‘ip’|‘email’|‘domain’, values: [‘192.168.1.1’, …]



92
93
94
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 92

def access_whitelist
  @access_whitelist
end

#activeObject

Required.



134
135
136
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 134

def active
  @active
end

#approval_statusObject

Approval status before marketplace publication



41
42
43
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 41

def approval_status
  @approval_status
end

#approved_atObject

Timestamp of marketplace approval



47
48
49
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 47

def approved_at
  @approved_at
end

#approved_by_user_idObject

User who approved this endpoint for marketplace



44
45
46
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 44

def approved_by_user_id
  @approved_by_user_id
end

#auc_idObject

Primary use case for marketplace discovery



38
39
40
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 38

def auc_id
  @auc_id
end

#company_idObject

References companies.company_id — A Spartera seller or buyer company account. See GET /companies for valid values. Required.



29
30
31
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 29

def company_id
  @company_id
end

#connection_idObject

Connection to the data source



32
33
34
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 32

def connection_id
  @connection_id
end

#customer_nameObject

Named customer for B2B deals (pricing handled via asset_price_history)



74
75
76
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 74

def customer_name
  @customer_name
end

#data_source_refresh_frequencyObject

How often the source data is refreshed



113
114
115
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 113

def data_source_refresh_frequency
  @data_source_refresh_frequency
end

#data_time_period_endObject

End date of the data time period covered



101
102
103
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 101

def data_time_period_end
  @data_time_period_end
end

#data_time_period_startObject

Start date of the data time period covered



98
99
100
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 98

def data_time_period_start
  @data_time_period_start
end

#date_collection_startObject

When the seller began actively collecting this data. Distinct from data_time_period_start, which describes when the records themselves begin. Backfilled historical data will have date_collection_start > data_time_period_start.



104
105
106
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 104

def date_collection_start
  @date_collection_start
end

#date_createdObject

Required.



20
21
22
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 20

def date_created
  @date_created
end

#descriptionObject

Description of what this endpoint provides



59
60
61
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 59

def description
  @description
end

#detailed_descriptionObject

Long-form HTML description for product pages and SEO



62
63
64
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 62

def detailed_description
  @detailed_description
end

#endpoint_schemaObject

Column configurations including aggregations, filters, and visibility. Format: [{name, type, aggregation, filter, is_hidden, alias, …]}. This is the source of truth — SQL is generated at runtime from this configuration.



77
78
79
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 77

def endpoint_schema
  @endpoint_schema
end

#export_enabledObject

Whether this endpoint supports bulk export to GCS. When True, buyers can request delivery=gcs with format=csv|parquet. Independent of max_records_per_request, which only governs inline JSON.



125
126
127
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 125

def export_enabled
  @export_enabled
end

#geographic_coverage_detailsObject

Specific regions/countries covered (e.g., ‘United States, Canada, Mexico’)



110
111
112
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 110

def geographic_coverage_details
  @geographic_coverage_details
end

#geographic_coverage_typeObject

Type of geographic coverage



107
108
109
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 107

def geographic_coverage_type
  @geographic_coverage_type
end

#industry_idObject

Industry / category for marketplace discovery



35
36
37
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 35

def industry_id
  @industry_id
end

#last_accessedObject

When this endpoint was last called



119
120
121
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 119

def last_accessed
  @last_accessed
end

#last_updatedObject

Required.



23
24
25
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 23

def last_updated
  @last_updated
end

#max_records_per_exportObject

Hard ceiling on rows returned per GCS export. Separate from max_records_per_request so sellers can offer larger downloads via file delivery without expanding inline JSON responses.



128
129
130
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 128

def max_records_per_export
  @max_records_per_export
end

#max_records_per_requestObject

Seller-enforced row cap per request. Buyers cannot exceed this. Default 1000.



122
123
124
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 122

def max_records_per_request
  @max_records_per_request
end

#nameObject

Human-readable name for the endpoint



53
54
55
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 53

def name
  @name
end

#rate_limit_granularityObject

How to group rate limits (IP, USER, COMPANY, API_KEY, GLOBAL)



86
87
88
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 86

def rate_limit_granularity
  @rate_limit_granularity
end

#rate_limit_numberObject

Number of requests allowed per rate_limit_period



80
81
82
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 80

def rate_limit_number
  @rate_limit_number
end

#rate_limit_periodObject

Time period for rate limiting (HOUR, DAY, MONTH)



83
84
85
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 83

def rate_limit_period
  @rate_limit_period
end

#sample_responseObject

Last successful request, response envelope. Saved on each successful marketplace run. Displayed as preview on product page load.



131
132
133
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 131

def sample_response
  @sample_response
end

#sell_in_marketplaceObject

Whether this endpoint appears in the public marketplace



50
51
52
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 50

def sell_in_marketplace
  @sell_in_marketplace
end

#slugObject

Human-readable, URL-safe slug derived from name at creation time. e.g. ‘NFL Live Moneyline & Spread Odds’ → ‘nfl-live-moneyline-spread-odds’. Never changes after creation. Unique within company (DB constraint). Creation fails with 409 if a duplicate name exists in the same company.



56
57
58
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 56

def slug
  @slug
end

#source_schema_nameObject

Schema/database name where the table resides



68
69
70
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 68

def source_schema_name
  @source_schema_name
end

#source_table_nameObject

Table name to query from



71
72
73
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 71

def source_table_name
  @source_table_name
end

#statusObject

Current status of the endpoint (ACTIVE, INACTIVE, DEPRECATED)



95
96
97
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 95

def status
  @status
end

#tagsObject

Comma-separated tags for organizing endpoints



116
117
118
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 116

def tags
  @tags
end

#top_questionsObject

Top 3 questions this endpoint can help answer, in English. Stored as JSON array of strings (1-3 items, 15-200 chars each). Strongly encouraged for marketplace endpoints but not required — nudge via UI completeness score, not hard validation.



65
66
67
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 65

def top_questions
  @top_questions
end

#user_idObject

User who created this endpoint



26
27
28
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 26

def user_id
  @user_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



204
205
206
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 204

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



209
210
211
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 209

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 159

def self.attribute_map
  {
    :'date_created' => :'date_created',
    :'last_updated' => :'last_updated',
    :'user_id' => :'user_id',
    :'company_id' => :'company_id',
    :'connection_id' => :'connection_id',
    :'industry_id' => :'industry_id',
    :'auc_id' => :'auc_id',
    :'approval_status' => :'approval_status',
    :'approved_by_user_id' => :'approved_by_user_id',
    :'approved_at' => :'approved_at',
    :'sell_in_marketplace' => :'sell_in_marketplace',
    :'name' => :'name',
    :'slug' => :'slug',
    :'description' => :'description',
    :'detailed_description' => :'detailed_description',
    :'top_questions' => :'top_questions',
    :'source_schema_name' => :'source_schema_name',
    :'source_table_name' => :'source_table_name',
    :'customer_name' => :'customer_name',
    :'endpoint_schema' => :'endpoint_schema',
    :'rate_limit_number' => :'rate_limit_number',
    :'rate_limit_period' => :'rate_limit_period',
    :'rate_limit_granularity' => :'rate_limit_granularity',
    :'access_method' => :'access_method',
    :'access_whitelist' => :'access_whitelist',
    :'status' => :'status',
    :'data_time_period_start' => :'data_time_period_start',
    :'data_time_period_end' => :'data_time_period_end',
    :'date_collection_start' => :'date_collection_start',
    :'geographic_coverage_type' => :'geographic_coverage_type',
    :'geographic_coverage_details' => :'geographic_coverage_details',
    :'data_source_refresh_frequency' => :'data_source_refresh_frequency',
    :'tags' => :'tags',
    :'last_accessed' => :'last_accessed',
    :'max_records_per_request' => :'max_records_per_request',
    :'export_enabled' => :'export_enabled',
    :'max_records_per_export' => :'max_records_per_export',
    :'sample_response' => :'sample_response',
    :'active' => :'active'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 648

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



259
260
261
262
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 259

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 214

def self.openapi_types
  {
    :'date_created' => :'Time',
    :'last_updated' => :'Time',
    :'user_id' => :'String',
    :'company_id' => :'String',
    :'connection_id' => :'String',
    :'industry_id' => :'Integer',
    :'auc_id' => :'Integer',
    :'approval_status' => :'String',
    :'approved_by_user_id' => :'String',
    :'approved_at' => :'Time',
    :'sell_in_marketplace' => :'Boolean',
    :'name' => :'String',
    :'slug' => :'String',
    :'description' => :'String',
    :'detailed_description' => :'String',
    :'top_questions' => :'String',
    :'source_schema_name' => :'String',
    :'source_table_name' => :'String',
    :'customer_name' => :'String',
    :'endpoint_schema' => :'Object',
    :'rate_limit_number' => :'Integer',
    :'rate_limit_period' => :'String',
    :'rate_limit_granularity' => :'String',
    :'access_method' => :'String',
    :'access_whitelist' => :'Object',
    :'status' => :'String',
    :'data_time_period_start' => :'Time',
    :'data_time_period_end' => :'Time',
    :'date_collection_start' => :'Time',
    :'geographic_coverage_type' => :'String',
    :'geographic_coverage_details' => :'String',
    :'data_source_refresh_frequency' => :'String',
    :'tags' => :'String',
    :'last_accessed' => :'Time',
    :'max_records_per_request' => :'Integer',
    :'export_enabled' => :'Boolean',
    :'max_records_per_export' => :'Integer',
    :'sample_response' => :'Object',
    :'active' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 589

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      date_created == o.date_created &&
      last_updated == o.last_updated &&
      user_id == o.user_id &&
      company_id == o.company_id &&
      connection_id == o.connection_id &&
      industry_id == o.industry_id &&
      auc_id == o.auc_id &&
      approval_status == o.approval_status &&
      approved_by_user_id == o.approved_by_user_id &&
      approved_at == o.approved_at &&
      sell_in_marketplace == o.sell_in_marketplace &&
      name == o.name &&
      slug == o.slug &&
      description == o.description &&
      detailed_description == o.detailed_description &&
      top_questions == o.top_questions &&
      source_schema_name == o.source_schema_name &&
      source_table_name == o.source_table_name &&
      customer_name == o.customer_name &&
      endpoint_schema == o.endpoint_schema &&
      rate_limit_number == o.rate_limit_number &&
      rate_limit_period == o.rate_limit_period &&
      rate_limit_granularity == o.rate_limit_granularity &&
      access_method == o.access_method &&
      access_whitelist == o.access_whitelist &&
      status == o.status &&
      data_time_period_start == o.data_time_period_start &&
      data_time_period_end == o.data_time_period_end &&
      date_collection_start == o.date_collection_start &&
      geographic_coverage_type == o.geographic_coverage_type &&
      geographic_coverage_details == o.geographic_coverage_details &&
      data_source_refresh_frequency == o.data_source_refresh_frequency &&
      tags == o.tags &&
      last_accessed == o.last_accessed &&
      max_records_per_request == o.max_records_per_request &&
      export_enabled == o.export_enabled &&
      max_records_per_export == o.max_records_per_export &&
      sample_response == o.sample_response &&
      active == o.active
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


635
636
637
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 635

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



641
642
643
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 641

def hash
  [date_created, last_updated, user_id, company_id, connection_id, industry_id, auc_id, approval_status, approved_by_user_id, approved_at, sell_in_marketplace, name, slug, description, detailed_description, top_questions, source_schema_name, source_table_name, customer_name, endpoint_schema, rate_limit_number, rate_limit_period, rate_limit_granularity, access_method, access_whitelist, status, data_time_period_start, data_time_period_end, date_collection_start, geographic_coverage_type, geographic_coverage_details, data_source_refresh_frequency, tags, last_accessed, max_records_per_request, export_enabled, max_records_per_export, sample_response, active].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 445

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @company_id.nil?
    invalid_properties.push('invalid value for "company_id", company_id cannot be nil.')
  end

  if @connection_id.nil?
    invalid_properties.push('invalid value for "connection_id", connection_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



670
671
672
673
674
675
676
677
678
679
680
681
682
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 670

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
# File 'lib/spartera_api_sdk/models/endpoints_input.rb', line 465

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @company_id.nil?
  return false if @connection_id.nil?
  approval_status_validator = EnumAttributeValidator.new('String', ["PENDING", "APPROVED", "REJECTED", "NEEDS_REVISION"])
  return false unless approval_status_validator.valid?(@approval_status)
  return false if @name.nil?
  rate_limit_period_validator = EnumAttributeValidator.new('String', ["SECOND", "MINUTE", "HOUR", "DAY"])
  return false unless rate_limit_period_validator.valid?(@rate_limit_period)
  rate_limit_granularity_validator = EnumAttributeValidator.new('String', ["USER", "COMPANY", "IP", "GLOBAL"])
  return false unless rate_limit_granularity_validator.valid?(@rate_limit_granularity)
  access_method_validator = EnumAttributeValidator.new('String', ["OPEN", "API_KEY", "IP", "EMAIL", "DOMAIN"])
  return false unless access_method_validator.valid?(@access_method)
  status_validator = EnumAttributeValidator.new('String', ["ACTIVE", "INACTIVE", "DEPRECATED"])
  return false unless status_validator.valid?(@status)
  geographic_coverage_type_validator = EnumAttributeValidator.new('String', ["GLOBAL", "CONTINENTAL", "REGIONAL", "NATIONAL", "STATE", "LOCAL", "CUSTOM", "UNKNOWN"])
  return false unless geographic_coverage_type_validator.valid?(@geographic_coverage_type)
  data_source_refresh_frequency_validator = EnumAttributeValidator.new('String', ["EVERY_SECOND", "EVERY_MINUTE", "EVERY_HOUR", "EVERY_DAY", "EVERY_WEEK", "EVERY_MONTH", "EVERY_QUARTER", "EVERY_YEAR", "NEVER", "UNKNOWN"])
  return false unless data_source_refresh_frequency_validator.valid?(@data_source_refresh_frequency)
  true
end