Class: SparteraApiSdk::Favorites

Inherits:
ApiModelBase show all
Defined in:
lib/spartera_api_sdk/models/favorites.rb

Overview

A saved marketplace asset in a user’s favorites library

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Favorites

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/spartera_api_sdk/models/favorites.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::Favorites` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::Favorites`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  end

  if attributes.key?(:'favorite_id')
    self.favorite_id = attributes[:'favorite_id']
  end

  if attributes.key?(:'asset_id')
    self.asset_id = attributes[:'asset_id']
  else
    self.asset_id = nil
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'company_id')
    self.company_id = attributes[:'company_id']
  else
    self.company_id = nil
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'priority')
    self.priority = attributes[:'priority']
  else
    self.priority = nil
  end
end

Instance Attribute Details

#asset_idObject

References assets.asset_id — A published analytics asset — a calculation or visualization built on a data connection. See GET /assets for valid values. Required.



29
30
31
# File 'lib/spartera_api_sdk/models/favorites.rb', line 29

def asset_id
  @asset_id
end

#categoryObject

Optional category for organizing favorites (e.g., ‘Work’, ‘Research’)



41
42
43
# File 'lib/spartera_api_sdk/models/favorites.rb', line 41

def category
  @category
end

#company_idObject

References companies.company_id — A Spartera seller or buyer company account. See GET /companies for valid values. Required.



35
36
37
# File 'lib/spartera_api_sdk/models/favorites.rb', line 35

def company_id
  @company_id
end

#date_createdObject

Optional.



20
21
22
# File 'lib/spartera_api_sdk/models/favorites.rb', line 20

def date_created
  @date_created
end

#favorite_idObject

Auto-generated unique identifier.



26
27
28
# File 'lib/spartera_api_sdk/models/favorites.rb', line 26

def favorite_id
  @favorite_id
end

#last_updatedObject

Optional.



23
24
25
# File 'lib/spartera_api_sdk/models/favorites.rb', line 23

def last_updated
  @last_updated
end

#notesObject

Optional user notes about this favorite



38
39
40
# File 'lib/spartera_api_sdk/models/favorites.rb', line 38

def notes
  @notes
end

#priorityObject

User-defined priority for sorting (higher = more important)



44
45
46
# File 'lib/spartera_api_sdk/models/favorites.rb', line 44

def priority
  @priority
end

#user_idObject

References users.user_id — An individual user account within a company. See GET /users for valid values. Optional.



32
33
34
# File 'lib/spartera_api_sdk/models/favorites.rb', line 32

def user_id
  @user_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/spartera_api_sdk/models/favorites.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/spartera_api_sdk/models/favorites.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/spartera_api_sdk/models/favorites.rb', line 47

def self.attribute_map
  {
    :'date_created' => :'date_created',
    :'last_updated' => :'last_updated',
    :'favorite_id' => :'favorite_id',
    :'asset_id' => :'asset_id',
    :'user_id' => :'user_id',
    :'company_id' => :'company_id',
    :'notes' => :'notes',
    :'category' => :'category',
    :'priority' => :'priority'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/spartera_api_sdk/models/favorites.rb', line 242

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/spartera_api_sdk/models/favorites.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/spartera_api_sdk/models/favorites.rb', line 72

def self.openapi_types
  {
    :'date_created' => :'Time',
    :'last_updated' => :'Time',
    :'favorite_id' => :'Integer',
    :'asset_id' => :'String',
    :'user_id' => :'String',
    :'company_id' => :'String',
    :'notes' => :'String',
    :'category' => :'String',
    :'priority' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/spartera_api_sdk/models/favorites.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      date_created == o.date_created &&
      last_updated == o.last_updated &&
      favorite_id == o.favorite_id &&
      asset_id == o.asset_id &&
      user_id == o.user_id &&
      company_id == o.company_id &&
      notes == o.notes &&
      category == o.category &&
      priority == o.priority
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


229
230
231
# File 'lib/spartera_api_sdk/models/favorites.rb', line 229

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



235
236
237
# File 'lib/spartera_api_sdk/models/favorites.rb', line 235

def hash
  [date_created, last_updated, favorite_id, asset_id, user_id, company_id, notes, category, priority].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/spartera_api_sdk/models/favorites.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @asset_id.nil?
    invalid_properties.push('invalid value for "asset_id", asset_id cannot be nil.')
  end

  if @company_id.nil?
    invalid_properties.push('invalid value for "company_id", company_id cannot be nil.')
  end

  if @priority.nil?
    invalid_properties.push('invalid value for "priority", priority cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/spartera_api_sdk/models/favorites.rb', line 264

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
177
178
179
# File 'lib/spartera_api_sdk/models/favorites.rb', line 173

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @asset_id.nil?
  return false if @company_id.nil?
  return false if @priority.nil?
  true
end