Class: SparteraApiSdk::FavoritesInput

Inherits:
ApiModelBase show all
Defined in:
lib/spartera_api_sdk/models/favorites_input.rb

Overview

Input schema for creating Favorite

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FavoritesInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::FavoritesInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::FavoritesInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'asset_id')
    self.asset_id = attributes[:'asset_id']
  else
    self.asset_id = nil
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'company_id')
    self.company_id = attributes[:'company_id']
  else
    self.company_id = nil
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'priority')
    self.priority = attributes[:'priority']
  end
end

Instance Attribute Details

#asset_idObject

References assets.asset_id — A published analytics asset — a calculation or visualization built on a data connection. See GET /assets for valid values. Required.



20
21
22
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 20

def asset_id
  @asset_id
end

#categoryObject

Optional category for organizing favorites (e.g., ‘Work’, ‘Research’)



32
33
34
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 32

def category
  @category
end

#company_idObject

References companies.company_id — A Spartera seller or buyer company account. See GET /companies for valid values. Required.



26
27
28
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 26

def company_id
  @company_id
end

#notesObject

Optional user notes about this favorite



29
30
31
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 29

def notes
  @notes
end

#priorityObject

User-defined priority for sorting (higher = more important)



35
36
37
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 35

def priority
  @priority
end

#user_idObject

References users.user_id — An individual user account within a company. See GET /users for valid values. Optional.



23
24
25
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 23

def user_id
  @user_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 38

def self.attribute_map
  {
    :'asset_id' => :'asset_id',
    :'user_id' => :'user_id',
    :'company_id' => :'company_id',
    :'notes' => :'notes',
    :'category' => :'category',
    :'priority' => :'priority'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 195

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 60

def self.openapi_types
  {
    :'asset_id' => :'String',
    :'user_id' => :'String',
    :'company_id' => :'String',
    :'notes' => :'String',
    :'category' => :'String',
    :'priority' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



169
170
171
172
173
174
175
176
177
178
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 169

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      asset_id == o.asset_id &&
      user_id == o.user_id &&
      company_id == o.company_id &&
      notes == o.notes &&
      category == o.category &&
      priority == o.priority
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


182
183
184
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 182

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



188
189
190
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 188

def hash
  [asset_id, user_id, company_id, notes, category, priority].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 124

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @asset_id.nil?
    invalid_properties.push('invalid value for "asset_id", asset_id cannot be nil.')
  end

  if @company_id.nil?
    invalid_properties.push('invalid value for "company_id", company_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 217

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



140
141
142
143
144
145
# File 'lib/spartera_api_sdk/models/favorites_input.rb', line 140

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @asset_id.nil?
  return false if @company_id.nil?
  true
end