Class: SparteraApiSdk::Industries

Inherits:
ApiModelBase show all
Defined in:
lib/spartera_api_sdk/models/industries.rb

Overview

Available industry categories for asset classification. Based on US NAISC codes.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Industries

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/spartera_api_sdk/models/industries.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::Industries` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::Industries`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  end

  if attributes.key?(:'industry_id')
    self.industry_id = attributes[:'industry_id']
  end

  if attributes.key?(:'industry_name')
    self.industry_name = attributes[:'industry_name']
  else
    self.industry_name = nil
  end

  if attributes.key?(:'short_name')
    self.short_name = attributes[:'short_name']
  else
    self.short_name = nil
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.key?(:'naisc_code')
    self.naisc_code = attributes[:'naisc_code']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end
end

Instance Attribute Details

#date_createdObject

Optional.



20
21
22
# File 'lib/spartera_api_sdk/models/industries.rb', line 20

def date_created
  @date_created
end

#descriptionObject

Optional.



41
42
43
# File 'lib/spartera_api_sdk/models/industries.rb', line 41

def description
  @description
end

#industry_idObject

Auto-generated unique identifier.



26
27
28
# File 'lib/spartera_api_sdk/models/industries.rb', line 26

def industry_id
  @industry_id
end

#industry_nameObject

Required. Must be unique.



29
30
31
# File 'lib/spartera_api_sdk/models/industries.rb', line 29

def industry_name
  @industry_name
end

#last_updatedObject

Optional.



23
24
25
# File 'lib/spartera_api_sdk/models/industries.rb', line 23

def last_updated
  @last_updated
end

#naisc_codeObject

Optional.



38
39
40
# File 'lib/spartera_api_sdk/models/industries.rb', line 38

def naisc_code
  @naisc_code
end

#short_nameObject

Required.



32
33
34
# File 'lib/spartera_api_sdk/models/industries.rb', line 32

def short_name
  @short_name
end

#slugObject

Optional.



35
36
37
# File 'lib/spartera_api_sdk/models/industries.rb', line 35

def slug
  @slug
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/spartera_api_sdk/models/industries.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/spartera_api_sdk/models/industries.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/spartera_api_sdk/models/industries.rb', line 44

def self.attribute_map
  {
    :'date_created' => :'date_created',
    :'last_updated' => :'last_updated',
    :'industry_id' => :'industry_id',
    :'industry_name' => :'industry_name',
    :'short_name' => :'short_name',
    :'slug' => :'slug',
    :'naisc_code' => :'naisc_code',
    :'description' => :'description'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/spartera_api_sdk/models/industries.rb', line 215

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/spartera_api_sdk/models/industries.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/spartera_api_sdk/models/industries.rb', line 68

def self.openapi_types
  {
    :'date_created' => :'Time',
    :'last_updated' => :'Time',
    :'industry_id' => :'Integer',
    :'industry_name' => :'String',
    :'short_name' => :'String',
    :'slug' => :'String',
    :'naisc_code' => :'Integer',
    :'description' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/spartera_api_sdk/models/industries.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      date_created == o.date_created &&
      last_updated == o.last_updated &&
      industry_id == o.industry_id &&
      industry_name == o.industry_name &&
      short_name == o.short_name &&
      slug == o.slug &&
      naisc_code == o.naisc_code &&
      description == o.description
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


202
203
204
# File 'lib/spartera_api_sdk/models/industries.rb', line 202

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



208
209
210
# File 'lib/spartera_api_sdk/models/industries.rb', line 208

def hash
  [date_created, last_updated, industry_id, industry_name, short_name, slug, naisc_code, description].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/spartera_api_sdk/models/industries.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @industry_name.nil?
    invalid_properties.push('invalid value for "industry_name", industry_name cannot be nil.')
  end

  if @short_name.nil?
    invalid_properties.push('invalid value for "short_name", short_name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/spartera_api_sdk/models/industries.rb', line 237

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



158
159
160
161
162
163
# File 'lib/spartera_api_sdk/models/industries.rb', line 158

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @industry_name.nil?
  return false if @short_name.nil?
  true
end