Class: SparteraApiSdk::PostPublicationsUpdate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SparteraApiSdk::PostPublicationsUpdate
- Defined in:
- lib/spartera_api_sdk/models/post_publications_update.rb
Overview
Update schema for modifying PostPublication
Instance Attribute Summary collapse
-
#company_id ⇒ Object
Company this publication belongs to.
-
#error_message ⇒ Object
Error message if publication failed.
-
#external_post_id ⇒ Object
ID of the post on the external platform.
-
#external_post_url ⇒ Object
URL to view the post on the external platform.
-
#integration_id ⇒ Object
Integration used for publishing.
-
#platform ⇒ Object
Platform identifier (beehiiv, wordpress, etc).
-
#post_id ⇒ Object
Post that was published.
-
#published_at ⇒ Object
When the post was published to this platform.
-
#status ⇒ Object
Status: published, failed, deleted.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PostPublicationsUpdate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PostPublicationsUpdate
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::PostPublicationsUpdate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::PostPublicationsUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'post_id') self.post_id = attributes[:'post_id'] end if attributes.key?(:'company_id') self.company_id = attributes[:'company_id'] end if attributes.key?(:'integration_id') self.integration_id = attributes[:'integration_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'external_post_id') self.external_post_id = attributes[:'external_post_id'] end if attributes.key?(:'external_post_url') self.external_post_url = attributes[:'external_post_url'] end if attributes.key?(:'published_at') self.published_at = attributes[:'published_at'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'error_message') self. = attributes[:'error_message'] end end |
Instance Attribute Details
#company_id ⇒ Object
Company this publication belongs to
23 24 25 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 23 def company_id @company_id end |
#error_message ⇒ Object
Error message if publication failed
44 45 46 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 44 def @error_message end |
#external_post_id ⇒ Object
ID of the post on the external platform
32 33 34 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 32 def external_post_id @external_post_id end |
#external_post_url ⇒ Object
URL to view the post on the external platform
35 36 37 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 35 def external_post_url @external_post_url end |
#integration_id ⇒ Object
Integration used for publishing
26 27 28 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 26 def integration_id @integration_id end |
#platform ⇒ Object
Platform identifier (beehiiv, wordpress, etc)
29 30 31 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 29 def platform @platform end |
#post_id ⇒ Object
Post that was published
20 21 22 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 20 def post_id @post_id end |
#published_at ⇒ Object
When the post was published to this platform
38 39 40 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 38 def published_at @published_at end |
#status ⇒ Object
Status: published, failed, deleted
41 42 43 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 41 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 47 def self.attribute_map { :'post_id' => :'post_id', :'company_id' => :'company_id', :'integration_id' => :'integration_id', :'platform' => :'platform', :'external_post_id' => :'external_post_id', :'external_post_url' => :'external_post_url', :'published_at' => :'published_at', :'status' => :'status', :'error_message' => :'error_message' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 72 def self.openapi_types { :'post_id' => :'String', :'company_id' => :'String', :'integration_id' => :'String', :'platform' => :'String', :'external_post_id' => :'String', :'external_post_url' => :'String', :'published_at' => :'Time', :'status' => :'String', :'error_message' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 162 def ==(o) return true if self.equal?(o) self.class == o.class && post_id == o.post_id && company_id == o.company_id && integration_id == o.integration_id && platform == o.platform && external_post_id == o.external_post_id && external_post_url == o.external_post_url && published_at == o.published_at && status == o.status && == o. end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 184 def hash [post_id, company_id, integration_id, platform, external_post_id, external_post_url, published_at, status, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 151 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 147 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
155 156 157 158 |
# File 'lib/spartera_api_sdk/models/post_publications_update.rb', line 155 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |