Class: SparteraApiSdk::PostgenIntegrations
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SparteraApiSdk::PostgenIntegrations
- Defined in:
- lib/spartera_api_sdk/models/postgen_integrations.rb
Overview
An external publishing platform integration for PostGen
Instance Attribute Summary collapse
-
#company_id ⇒ Object
Company this integration belongs to.
-
#credentials_secret_name ⇒ Object
GCP Secret Manager secret name containing encrypted credentials.
-
#date_created ⇒ Object
Optional.
-
#integration_id ⇒ Object
Unique identifier.
-
#is_active ⇒ Object
Whether this integration is currently active.
-
#last_updated ⇒ Object
Optional.
-
#last_used_at ⇒ Object
Last time this integration was used for publishing.
-
#platform ⇒ Object
Platform identifier (beehiiv, wordpress, medium, etc).
-
#platform_name ⇒ Object
Display name of the platform.
-
#user_id ⇒ Object
User who created this integration.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PostgenIntegrations
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PostgenIntegrations
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::PostgenIntegrations` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::PostgenIntegrations`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'date_created') self.date_created = attributes[:'date_created'] end if attributes.key?(:'last_updated') self.last_updated = attributes[:'last_updated'] end if attributes.key?(:'integration_id') self.integration_id = attributes[:'integration_id'] end if attributes.key?(:'company_id') self.company_id = attributes[:'company_id'] else self.company_id = nil end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] else self.user_id = nil end if attributes.key?(:'platform') self.platform = attributes[:'platform'] else self.platform = nil end if attributes.key?(:'platform_name') self.platform_name = attributes[:'platform_name'] else self.platform_name = nil end if attributes.key?(:'credentials_secret_name') self.credentials_secret_name = attributes[:'credentials_secret_name'] else self.credentials_secret_name = nil end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] else self.is_active = nil end if attributes.key?(:'last_used_at') self.last_used_at = attributes[:'last_used_at'] end end |
Instance Attribute Details
#company_id ⇒ Object
Company this integration belongs to
29 30 31 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 29 def company_id @company_id end |
#credentials_secret_name ⇒ Object
GCP Secret Manager secret name containing encrypted credentials
41 42 43 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 41 def credentials_secret_name @credentials_secret_name end |
#date_created ⇒ Object
Optional.
20 21 22 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 20 def date_created @date_created end |
#integration_id ⇒ Object
Unique identifier.
26 27 28 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 26 def integration_id @integration_id end |
#is_active ⇒ Object
Whether this integration is currently active
44 45 46 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 44 def is_active @is_active end |
#last_updated ⇒ Object
Optional.
23 24 25 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 23 def last_updated @last_updated end |
#last_used_at ⇒ Object
Last time this integration was used for publishing
47 48 49 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 47 def last_used_at @last_used_at end |
#platform ⇒ Object
Platform identifier (beehiiv, wordpress, medium, etc)
35 36 37 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 35 def platform @platform end |
#platform_name ⇒ Object
Display name of the platform
38 39 40 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 38 def platform_name @platform_name end |
#user_id ⇒ Object
User who created this integration
32 33 34 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 32 def user_id @user_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 50 def self.attribute_map { :'date_created' => :'date_created', :'last_updated' => :'last_updated', :'integration_id' => :'integration_id', :'company_id' => :'company_id', :'user_id' => :'user_id', :'platform' => :'platform', :'platform_name' => :'platform_name', :'credentials_secret_name' => :'credentials_secret_name', :'is_active' => :'is_active', :'last_used_at' => :'last_used_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 303 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 92 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 76 def self.openapi_types { :'date_created' => :'Time', :'last_updated' => :'Time', :'integration_id' => :'String', :'company_id' => :'String', :'user_id' => :'String', :'platform' => :'String', :'platform_name' => :'String', :'credentials_secret_name' => :'String', :'is_active' => :'Boolean', :'last_used_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 273 def ==(o) return true if self.equal?(o) self.class == o.class && date_created == o.date_created && last_updated == o.last_updated && integration_id == o.integration_id && company_id == o.company_id && user_id == o.user_id && platform == o.platform && platform_name == o.platform_name && credentials_secret_name == o.credentials_secret_name && is_active == o.is_active && last_used_at == o.last_used_at end |
#eql?(o) ⇒ Boolean
290 291 292 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 290 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
296 297 298 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 296 def hash [date_created, last_updated, integration_id, company_id, user_id, platform, platform_name, credentials_secret_name, is_active, last_used_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 168 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @company_id.nil? invalid_properties.push('invalid value for "company_id", company_id cannot be nil.') end if @user_id.nil? invalid_properties.push('invalid value for "user_id", user_id cannot be nil.') end if @platform.nil? invalid_properties.push('invalid value for "platform", platform cannot be nil.') end if @platform_name.nil? invalid_properties.push('invalid value for "platform_name", platform_name cannot be nil.') end if @credentials_secret_name.nil? invalid_properties.push('invalid value for "credentials_secret_name", credentials_secret_name cannot be nil.') end if @is_active.nil? invalid_properties.push('invalid value for "is_active", is_active cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 325 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
200 201 202 203 204 205 206 207 208 209 |
# File 'lib/spartera_api_sdk/models/postgen_integrations.rb', line 200 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @company_id.nil? return false if @user_id.nil? return false if @platform.nil? return false if @platform_name.nil? return false if @credentials_secret_name.nil? return false if @is_active.nil? true end |