Class: SparteraApiSdk::Users

Inherits:
ApiModelBase show all
Defined in:
lib/spartera_api_sdk/models/users.rb

Overview

An individual user account within a company

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Users

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/spartera_api_sdk/models/users.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::Users` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::Users`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'company_id')
    self.company_id = attributes[:'company_id']
  else
    self.company_id = nil
  end

  if attributes.key?(:'role_id')
    self.role_id = attributes[:'role_id']
  else
    self.role_id = nil
  end

  if attributes.key?(:'function_id')
    self.function_id = attributes[:'function_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'email_address')
    self.email_address = attributes[:'email_address']
  end

  if attributes.key?(:'timezone')
    self.timezone = attributes[:'timezone']
  end

  if attributes.key?(:'marketing_opt_out')
    self.marketing_opt_out = attributes[:'marketing_opt_out']
  else
    self.marketing_opt_out = nil
  end
end

Instance Attribute Details

#company_idObject

References companies.company_id — A Spartera seller or buyer company account. See GET /companies for valid values. Required.



29
30
31
# File 'lib/spartera_api_sdk/models/users.rb', line 29

def company_id
  @company_id
end

#date_createdObject

Optional.



20
21
22
# File 'lib/spartera_api_sdk/models/users.rb', line 20

def date_created
  @date_created
end

#email_addressObject

Optional. Must be unique.



41
42
43
# File 'lib/spartera_api_sdk/models/users.rb', line 41

def email_address
  @email_address
end

#function_idObject

User’s job function/title



35
36
37
# File 'lib/spartera_api_sdk/models/users.rb', line 35

def function_id
  @function_id
end

#last_updatedObject

Optional.



23
24
25
# File 'lib/spartera_api_sdk/models/users.rb', line 23

def last_updated
  @last_updated
end

#marketing_opt_outObject

Whether user has opted out of marketing communications. Default false = opted in per ToS.



47
48
49
# File 'lib/spartera_api_sdk/models/users.rb', line 47

def marketing_opt_out
  @marketing_opt_out
end

#role_idObject

User’s role for RBAC - single source of truth



32
33
34
# File 'lib/spartera_api_sdk/models/users.rb', line 32

def role_id
  @role_id
end

#statusObject

Required. One of: ACTIVE, PENDING, INACTIVE, BANNED.



38
39
40
# File 'lib/spartera_api_sdk/models/users.rb', line 38

def status
  @status
end

#timezoneObject

Optional.



44
45
46
# File 'lib/spartera_api_sdk/models/users.rb', line 44

def timezone
  @timezone
end

#user_idObject

Unique identifier.



26
27
28
# File 'lib/spartera_api_sdk/models/users.rb', line 26

def user_id
  @user_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



88
89
90
# File 'lib/spartera_api_sdk/models/users.rb', line 88

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



93
94
95
# File 'lib/spartera_api_sdk/models/users.rb', line 93

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/spartera_api_sdk/models/users.rb', line 72

def self.attribute_map
  {
    :'date_created' => :'date_created',
    :'last_updated' => :'last_updated',
    :'user_id' => :'user_id',
    :'company_id' => :'company_id',
    :'role_id' => :'role_id',
    :'function_id' => :'function_id',
    :'status' => :'status',
    :'email_address' => :'email_address',
    :'timezone' => :'timezone',
    :'marketing_opt_out' => :'marketing_opt_out'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/spartera_api_sdk/models/users.rb', line 293

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
# File 'lib/spartera_api_sdk/models/users.rb', line 114

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/spartera_api_sdk/models/users.rb', line 98

def self.openapi_types
  {
    :'date_created' => :'Time',
    :'last_updated' => :'Time',
    :'user_id' => :'String',
    :'company_id' => :'String',
    :'role_id' => :'Integer',
    :'function_id' => :'Integer',
    :'status' => :'String',
    :'email_address' => :'String',
    :'timezone' => :'String',
    :'marketing_opt_out' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/spartera_api_sdk/models/users.rb', line 263

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      date_created == o.date_created &&
      last_updated == o.last_updated &&
      user_id == o.user_id &&
      company_id == o.company_id &&
      role_id == o.role_id &&
      function_id == o.function_id &&
      status == o.status &&
      email_address == o.email_address &&
      timezone == o.timezone &&
      marketing_opt_out == o.marketing_opt_out
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


280
281
282
# File 'lib/spartera_api_sdk/models/users.rb', line 280

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



286
287
288
# File 'lib/spartera_api_sdk/models/users.rb', line 286

def hash
  [date_created, last_updated, user_id, company_id, role_id, function_id, status, email_address, timezone, marketing_opt_out].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/spartera_api_sdk/models/users.rb', line 186

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @company_id.nil?
    invalid_properties.push('invalid value for "company_id", company_id cannot be nil.')
  end

  if @role_id.nil?
    invalid_properties.push('invalid value for "role_id", role_id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @marketing_opt_out.nil?
    invalid_properties.push('invalid value for "marketing_opt_out", marketing_opt_out cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/spartera_api_sdk/models/users.rb', line 315

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



210
211
212
213
214
215
216
217
218
219
# File 'lib/spartera_api_sdk/models/users.rb', line 210

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @company_id.nil?
  return false if @role_id.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["ACTIVE", "PENDING", "INACTIVE", "BANNED"])
  return false unless status_validator.valid?(@status)
  return false if @marketing_opt_out.nil?
  true
end