Class: SparteraApiSdk::UsersInput

Inherits:
ApiModelBase show all
Defined in:
lib/spartera_api_sdk/models/users_input.rb

Overview

Input schema for creating User

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UsersInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/spartera_api_sdk/models/users_input.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::UsersInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::UsersInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'company_id')
    self.company_id = attributes[:'company_id']
  else
    self.company_id = nil
  end

  if attributes.key?(:'role_id')
    self.role_id = attributes[:'role_id']
  end

  if attributes.key?(:'function_id')
    self.function_id = attributes[:'function_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'email_address')
    self.email_address = attributes[:'email_address']
  end

  if attributes.key?(:'timezone')
    self.timezone = attributes[:'timezone']
  end

  if attributes.key?(:'marketing_opt_out')
    self.marketing_opt_out = attributes[:'marketing_opt_out']
  end
end

Instance Attribute Details

#company_idObject

References companies.company_id — A Spartera seller or buyer company account. See GET /companies for valid values. Required.



20
21
22
# File 'lib/spartera_api_sdk/models/users_input.rb', line 20

def company_id
  @company_id
end

#email_addressObject

Optional. Must be unique.



32
33
34
# File 'lib/spartera_api_sdk/models/users_input.rb', line 32

def email_address
  @email_address
end

#function_idObject

User’s job function/title



26
27
28
# File 'lib/spartera_api_sdk/models/users_input.rb', line 26

def function_id
  @function_id
end

#marketing_opt_outObject

Whether user has opted out of marketing communications. Default false = opted in per ToS.



38
39
40
# File 'lib/spartera_api_sdk/models/users_input.rb', line 38

def marketing_opt_out
  @marketing_opt_out
end

#role_idObject

User’s role for RBAC - single source of truth



23
24
25
# File 'lib/spartera_api_sdk/models/users_input.rb', line 23

def role_id
  @role_id
end

#statusObject

Required. One of: ACTIVE, PENDING, INACTIVE, BANNED.



29
30
31
# File 'lib/spartera_api_sdk/models/users_input.rb', line 29

def status
  @status
end

#timezoneObject

Optional.



35
36
37
# File 'lib/spartera_api_sdk/models/users_input.rb', line 35

def timezone
  @timezone
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



76
77
78
# File 'lib/spartera_api_sdk/models/users_input.rb', line 76

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/spartera_api_sdk/models/users_input.rb', line 81

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/spartera_api_sdk/models/users_input.rb', line 63

def self.attribute_map
  {
    :'company_id' => :'company_id',
    :'role_id' => :'role_id',
    :'function_id' => :'function_id',
    :'status' => :'status',
    :'email_address' => :'email_address',
    :'timezone' => :'timezone',
    :'marketing_opt_out' => :'marketing_opt_out'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/spartera_api_sdk/models/users_input.rb', line 222

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
# File 'lib/spartera_api_sdk/models/users_input.rb', line 99

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
# File 'lib/spartera_api_sdk/models/users_input.rb', line 86

def self.openapi_types
  {
    :'company_id' => :'String',
    :'role_id' => :'Integer',
    :'function_id' => :'Integer',
    :'status' => :'String',
    :'email_address' => :'String',
    :'timezone' => :'String',
    :'marketing_opt_out' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



195
196
197
198
199
200
201
202
203
204
205
# File 'lib/spartera_api_sdk/models/users_input.rb', line 195

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      company_id == o.company_id &&
      role_id == o.role_id &&
      function_id == o.function_id &&
      status == o.status &&
      email_address == o.email_address &&
      timezone == o.timezone &&
      marketing_opt_out == o.marketing_opt_out
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


209
210
211
# File 'lib/spartera_api_sdk/models/users_input.rb', line 209

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



215
216
217
# File 'lib/spartera_api_sdk/models/users_input.rb', line 215

def hash
  [company_id, role_id, function_id, status, email_address, timezone, marketing_opt_out].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
158
159
160
161
# File 'lib/spartera_api_sdk/models/users_input.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @company_id.nil?
    invalid_properties.push('invalid value for "company_id", company_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/spartera_api_sdk/models/users_input.rb', line 244

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



165
166
167
168
169
170
171
# File 'lib/spartera_api_sdk/models/users_input.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @company_id.nil?
  status_validator = EnumAttributeValidator.new('String', ["ACTIVE", "PENDING", "INACTIVE", "BANNED"])
  return false unless status_validator.valid?(@status)
  true
end