Class: SparteraApiSdk::AssetPriceHistory
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SparteraApiSdk::AssetPriceHistory
- Defined in:
- lib/spartera_api_sdk/models/asset_price_history.rb
Overview
Per-execution pricing history for a marketplace asset
Instance Attribute Summary collapse
-
#aph_id ⇒ Object
Unique identifier.
-
#asset_id ⇒ Object
FK to assets.
-
#date_created ⇒ Object
Optional.
-
#date_ended ⇒ Object
SCD Type 2 — when this price record was superseded.
-
#endpoint_id ⇒ Object
FK to endpoints.
-
#last_updated ⇒ Object
Optional.
-
#price_usd ⇒ Object
Optional.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AssetPriceHistory
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AssetPriceHistory
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::AssetPriceHistory` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::AssetPriceHistory`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'date_created') self.date_created = attributes[:'date_created'] end if attributes.key?(:'last_updated') self.last_updated = attributes[:'last_updated'] end if attributes.key?(:'aph_id') self.aph_id = attributes[:'aph_id'] end if attributes.key?(:'asset_id') self.asset_id = attributes[:'asset_id'] end if attributes.key?(:'endpoint_id') self.endpoint_id = attributes[:'endpoint_id'] end if attributes.key?(:'price_usd') self.price_usd = attributes[:'price_usd'] end if attributes.key?(:'date_ended') self.date_ended = attributes[:'date_ended'] end end |
Instance Attribute Details
#aph_id ⇒ Object
Unique identifier.
26 27 28 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 26 def aph_id @aph_id end |
#asset_id ⇒ Object
FK to assets. NULL when this record belongs to an endpoint.
29 30 31 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 29 def asset_id @asset_id end |
#date_created ⇒ Object
Optional.
20 21 22 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 20 def date_created @date_created end |
#date_ended ⇒ Object
SCD Type 2 — when this price record was superseded
38 39 40 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 38 def date_ended @date_ended end |
#endpoint_id ⇒ Object
FK to endpoints. NULL when this record belongs to an asset.
32 33 34 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 32 def endpoint_id @endpoint_id end |
#last_updated ⇒ Object
Optional.
23 24 25 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 23 def last_updated @last_updated end |
#price_usd ⇒ Object
Optional.
35 36 37 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 35 def price_usd @price_usd end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 41 def self.attribute_map { :'date_created' => :'date_created', :'last_updated' => :'last_updated', :'aph_id' => :'aph_id', :'asset_id' => :'asset_id', :'endpoint_id' => :'endpoint_id', :'price_usd' => :'price_usd', :'date_ended' => :'date_ended' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 171 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 64 def self.openapi_types { :'date_created' => :'Time', :'last_updated' => :'Time', :'aph_id' => :'String', :'asset_id' => :'String', :'endpoint_id' => :'String', :'price_usd' => :'Float', :'date_ended' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 144 def ==(o) return true if self.equal?(o) self.class == o.class && date_created == o.date_created && last_updated == o.last_updated && aph_id == o.aph_id && asset_id == o.asset_id && endpoint_id == o.endpoint_id && price_usd == o.price_usd && date_ended == o.date_ended end |
#eql?(o) ⇒ Boolean
158 159 160 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 158 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
164 165 166 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 164 def hash [date_created, last_updated, aph_id, asset_id, endpoint_id, price_usd, date_ended].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 193 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 |
# File 'lib/spartera_api_sdk/models/asset_price_history.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |