Class: SparteraApiSdk::Connections

Inherits:
ApiModelBase show all
Defined in:
lib/spartera_api_sdk/models/connections.rb

Overview

Secure connections from Spartera to your databases and data warehouses

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Connections

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/spartera_api_sdk/models/connections.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::Connections` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::Connections`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'date_created')
    self.date_created = attributes[:'date_created']
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  end

  if attributes.key?(:'connection_id')
    self.connection_id = attributes[:'connection_id']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'engine_id')
    self.engine_id = attributes[:'engine_id']
  else
    self.engine_id = nil
  end

  if attributes.key?(:'company_id')
    self.company_id = attributes[:'company_id']
  else
    self.company_id = nil
  end

  if attributes.key?(:'credential_type')
    self.credential_type = attributes[:'credential_type']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'provider_domain')
    self.provider_domain = attributes[:'provider_domain']
  end

  if attributes.key?(:'verified_usage_ability')
    self.verified_usage_ability = attributes[:'verified_usage_ability']
  end
end

Instance Attribute Details

#company_idObject

References companies.company_id — A Spartera seller or buyer company account. See GET /companies for valid values. Required.



35
36
37
# File 'lib/spartera_api_sdk/models/connections.rb', line 35

def company_id
  @company_id
end

#connection_idObject

Unique identifier.



26
27
28
# File 'lib/spartera_api_sdk/models/connections.rb', line 26

def connection_id
  @connection_id
end

#credential_typeObject

Optional. One of: SERVICE_ACCOUNT, USERNAME_PASSWORD, API_KEY, SERVICE_IDENTITY, ACCESS_KEY, … (8 total).



38
39
40
# File 'lib/spartera_api_sdk/models/connections.rb', line 38

def credential_type
  @credential_type
end

#date_createdObject

Optional.



20
21
22
# File 'lib/spartera_api_sdk/models/connections.rb', line 20

def date_created
  @date_created
end

#descriptionObject

Optional.



44
45
46
# File 'lib/spartera_api_sdk/models/connections.rb', line 44

def description
  @description
end

#engine_idObject

References storage_engines.engine_id — Fact table of all the different storage engines we support. See GET /storage_engines for valid values. Required.



32
33
34
# File 'lib/spartera_api_sdk/models/connections.rb', line 32

def engine_id
  @engine_id
end

#last_updatedObject

Optional.



23
24
25
# File 'lib/spartera_api_sdk/models/connections.rb', line 23

def last_updated
  @last_updated
end

#nameObject

Optional.



41
42
43
# File 'lib/spartera_api_sdk/models/connections.rb', line 41

def name
  @name
end

#provider_domainObject

Domain of the external API provider (e.g., ‘api.weather.com’)



47
48
49
# File 'lib/spartera_api_sdk/models/connections.rb', line 47

def provider_domain
  @provider_domain
end

#user_idObject

References users.user_id — An individual user account within a company. See GET /users for valid values. Optional.



29
30
31
# File 'lib/spartera_api_sdk/models/connections.rb', line 29

def user_id
  @user_id
end

#verified_usage_abilityObject

Optional.



50
51
52
# File 'lib/spartera_api_sdk/models/connections.rb', line 50

def verified_usage_ability
  @verified_usage_ability
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



92
93
94
# File 'lib/spartera_api_sdk/models/connections.rb', line 92

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



97
98
99
# File 'lib/spartera_api_sdk/models/connections.rb', line 97

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/spartera_api_sdk/models/connections.rb', line 75

def self.attribute_map
  {
    :'date_created' => :'date_created',
    :'last_updated' => :'last_updated',
    :'connection_id' => :'connection_id',
    :'user_id' => :'user_id',
    :'engine_id' => :'engine_id',
    :'company_id' => :'company_id',
    :'credential_type' => :'credential_type',
    :'name' => :'name',
    :'description' => :'description',
    :'provider_domain' => :'provider_domain',
    :'verified_usage_ability' => :'verified_usage_ability'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/spartera_api_sdk/models/connections.rb', line 279

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



119
120
121
122
# File 'lib/spartera_api_sdk/models/connections.rb', line 119

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/spartera_api_sdk/models/connections.rb', line 102

def self.openapi_types
  {
    :'date_created' => :'Time',
    :'last_updated' => :'Time',
    :'connection_id' => :'String',
    :'user_id' => :'String',
    :'engine_id' => :'Integer',
    :'company_id' => :'String',
    :'credential_type' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'provider_domain' => :'String',
    :'verified_usage_ability' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/spartera_api_sdk/models/connections.rb', line 248

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      date_created == o.date_created &&
      last_updated == o.last_updated &&
      connection_id == o.connection_id &&
      user_id == o.user_id &&
      engine_id == o.engine_id &&
      company_id == o.company_id &&
      credential_type == o.credential_type &&
      name == o.name &&
      description == o.description &&
      provider_domain == o.provider_domain &&
      verified_usage_ability == o.verified_usage_ability
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


266
267
268
# File 'lib/spartera_api_sdk/models/connections.rb', line 266

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



272
273
274
# File 'lib/spartera_api_sdk/models/connections.rb', line 272

def hash
  [date_created, last_updated, connection_id, user_id, engine_id, company_id, credential_type, name, description, provider_domain, verified_usage_ability].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/spartera_api_sdk/models/connections.rb', line 191

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @engine_id.nil?
    invalid_properties.push('invalid value for "engine_id", engine_id cannot be nil.')
  end

  if @company_id.nil?
    invalid_properties.push('invalid value for "company_id", company_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/spartera_api_sdk/models/connections.rb', line 301

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



207
208
209
210
211
212
213
214
# File 'lib/spartera_api_sdk/models/connections.rb', line 207

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @engine_id.nil?
  return false if @company_id.nil?
  credential_type_validator = EnumAttributeValidator.new('String', ["SERVICE_ACCOUNT", "USERNAME_PASSWORD", "API_KEY", "SERVICE_IDENTITY", "ACCESS_KEY", "NONE", "OAUTH", "JSON"])
  return false unless credential_type_validator.valid?(@credential_type)
  true
end