Class: SparteraApiSdk::ConnectionsUpdate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SparteraApiSdk::ConnectionsUpdate
- Defined in:
- lib/spartera_api_sdk/models/connections_update.rb
Overview
Update schema for modifying Connection
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#company_id ⇒ Object
References companies.company_id — A Spartera seller or buyer company account.
-
#credential_type ⇒ Object
Optional.
-
#description ⇒ Object
Optional.
-
#engine_id ⇒ Object
References storage_engines.engine_id — Fact table of all the different storage engines we support.
-
#name ⇒ Object
Optional.
-
#provider_domain ⇒ Object
Domain of the external API provider (e.g., ‘api.weather.com’).
-
#user_id ⇒ Object
References users.user_id — An individual user account within a company.
-
#verified_usage_ability ⇒ Object
Optional.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConnectionsUpdate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConnectionsUpdate
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::ConnectionsUpdate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::ConnectionsUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'engine_id') self.engine_id = attributes[:'engine_id'] end if attributes.key?(:'company_id') self.company_id = attributes[:'company_id'] end if attributes.key?(:'credential_type') self.credential_type = attributes[:'credential_type'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'provider_domain') self.provider_domain = attributes[:'provider_domain'] end if attributes.key?(:'verified_usage_ability') self.verified_usage_ability = attributes[:'verified_usage_ability'] end end |
Instance Attribute Details
#company_id ⇒ Object
References companies.company_id — A Spartera seller or buyer company account. See GET /companies for valid values. Required.
26 27 28 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 26 def company_id @company_id end |
#credential_type ⇒ Object
Optional. One of: SERVICE_ACCOUNT, USERNAME_PASSWORD, API_KEY, SERVICE_IDENTITY, ACCESS_KEY, … (8 total).
29 30 31 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 29 def credential_type @credential_type end |
#description ⇒ Object
Optional.
35 36 37 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 35 def description @description end |
#engine_id ⇒ Object
References storage_engines.engine_id — Fact table of all the different storage engines we support. See GET /storage_engines for valid values. Required.
23 24 25 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 23 def engine_id @engine_id end |
#name ⇒ Object
Optional.
32 33 34 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 32 def name @name end |
#provider_domain ⇒ Object
Domain of the external API provider (e.g., ‘api.weather.com’)
38 39 40 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 38 def provider_domain @provider_domain end |
#user_id ⇒ Object
References users.user_id — An individual user account within a company. See GET /users for valid values. Optional.
20 21 22 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 20 def user_id @user_id end |
#verified_usage_ability ⇒ Object
Optional.
41 42 43 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 41 def verified_usage_ability @verified_usage_ability end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
80 81 82 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 80 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 85 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 66 def self.attribute_map { :'user_id' => :'user_id', :'engine_id' => :'engine_id', :'company_id' => :'company_id', :'credential_type' => :'credential_type', :'name' => :'name', :'description' => :'description', :'provider_domain' => :'provider_domain', :'verified_usage_ability' => :'verified_usage_ability' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 215 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 104 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 90 def self.openapi_types { :'user_id' => :'String', :'engine_id' => :'Integer', :'company_id' => :'String', :'credential_type' => :'String', :'name' => :'String', :'description' => :'String', :'provider_domain' => :'String', :'verified_usage_ability' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 187 def ==(o) return true if self.equal?(o) self.class == o.class && user_id == o.user_id && engine_id == o.engine_id && company_id == o.company_id && credential_type == o.credential_type && name == o.name && description == o.description && provider_domain == o.provider_domain && verified_usage_ability == o.verified_usage_ability end |
#eql?(o) ⇒ Boolean
202 203 204 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 202 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
208 209 210 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 208 def hash [user_id, engine_id, company_id, credential_type, name, description, provider_domain, verified_usage_ability].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
160 161 162 163 164 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 160 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 237 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
168 169 170 171 172 173 |
# File 'lib/spartera_api_sdk/models/connections_update.rb', line 168 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' credential_type_validator = EnumAttributeValidator.new('String', ["SERVICE_ACCOUNT", "USERNAME_PASSWORD", "API_KEY", "SERVICE_IDENTITY", "ACCESS_KEY", "NONE", "OAUTH", "JSON"]) return false unless credential_type_validator.valid?(@credential_type) true end |