Class: SparteraApiSdk::PostPublications
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SparteraApiSdk::PostPublications
- Defined in:
- lib/spartera_api_sdk/models/post_publications.rb
Overview
Tracks where posts have been published to external platforms
Instance Attribute Summary collapse
-
#company_id ⇒ Object
Company this publication belongs to.
-
#date_created ⇒ Object
Optional.
-
#error_message ⇒ Object
Error message if publication failed.
-
#external_post_id ⇒ Object
ID of the post on the external platform.
-
#external_post_url ⇒ Object
URL to view the post on the external platform.
-
#integration_id ⇒ Object
Integration used for publishing.
-
#last_updated ⇒ Object
Optional.
-
#platform ⇒ Object
Platform identifier (beehiiv, wordpress, etc).
-
#post_id ⇒ Object
Post that was published.
-
#publication_id ⇒ Object
Unique identifier.
-
#published_at ⇒ Object
When the post was published to this platform.
-
#status ⇒ Object
Status: published, failed, deleted.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PostPublications
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PostPublications
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::PostPublications` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::PostPublications`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'date_created') self.date_created = attributes[:'date_created'] end if attributes.key?(:'last_updated') self.last_updated = attributes[:'last_updated'] end if attributes.key?(:'publication_id') self.publication_id = attributes[:'publication_id'] end if attributes.key?(:'post_id') self.post_id = attributes[:'post_id'] else self.post_id = nil end if attributes.key?(:'company_id') self.company_id = attributes[:'company_id'] else self.company_id = nil end if attributes.key?(:'integration_id') self.integration_id = attributes[:'integration_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] else self.platform = nil end if attributes.key?(:'external_post_id') self.external_post_id = attributes[:'external_post_id'] end if attributes.key?(:'external_post_url') self.external_post_url = attributes[:'external_post_url'] end if attributes.key?(:'published_at') self.published_at = attributes[:'published_at'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'error_message') self. = attributes[:'error_message'] end end |
Instance Attribute Details
#company_id ⇒ Object
Company this publication belongs to
32 33 34 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 32 def company_id @company_id end |
#date_created ⇒ Object
Optional.
20 21 22 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 20 def date_created @date_created end |
#error_message ⇒ Object
Error message if publication failed
53 54 55 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 53 def @error_message end |
#external_post_id ⇒ Object
ID of the post on the external platform
41 42 43 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 41 def external_post_id @external_post_id end |
#external_post_url ⇒ Object
URL to view the post on the external platform
44 45 46 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 44 def external_post_url @external_post_url end |
#integration_id ⇒ Object
Integration used for publishing
35 36 37 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 35 def integration_id @integration_id end |
#last_updated ⇒ Object
Optional.
23 24 25 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 23 def last_updated @last_updated end |
#platform ⇒ Object
Platform identifier (beehiiv, wordpress, etc)
38 39 40 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 38 def platform @platform end |
#post_id ⇒ Object
Post that was published
29 30 31 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 29 def post_id @post_id end |
#publication_id ⇒ Object
Unique identifier.
26 27 28 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 26 def publication_id @publication_id end |
#published_at ⇒ Object
When the post was published to this platform
47 48 49 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 47 def published_at @published_at end |
#status ⇒ Object
Status: published, failed, deleted
50 51 52 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 50 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 56 def self.attribute_map { :'date_created' => :'date_created', :'last_updated' => :'last_updated', :'publication_id' => :'publication_id', :'post_id' => :'post_id', :'company_id' => :'company_id', :'integration_id' => :'integration_id', :'platform' => :'platform', :'external_post_id' => :'external_post_id', :'external_post_url' => :'external_post_url', :'published_at' => :'published_at', :'status' => :'status', :'error_message' => :'error_message' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 289 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 102 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 84 def self.openapi_types { :'date_created' => :'Time', :'last_updated' => :'Time', :'publication_id' => :'String', :'post_id' => :'String', :'company_id' => :'String', :'integration_id' => :'String', :'platform' => :'String', :'external_post_id' => :'String', :'external_post_url' => :'String', :'published_at' => :'Time', :'status' => :'String', :'error_message' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 257 def ==(o) return true if self.equal?(o) self.class == o.class && date_created == o.date_created && last_updated == o.last_updated && publication_id == o.publication_id && post_id == o.post_id && company_id == o.company_id && integration_id == o.integration_id && platform == o.platform && external_post_id == o.external_post_id && external_post_url == o.external_post_url && published_at == o.published_at && status == o.status && == o. end |
#eql?(o) ⇒ Boolean
276 277 278 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 276 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
282 283 284 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 282 def hash [date_created, last_updated, publication_id, post_id, company_id, integration_id, platform, external_post_id, external_post_url, published_at, status, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 182 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @post_id.nil? invalid_properties.push('invalid value for "post_id", post_id cannot be nil.') end if @company_id.nil? invalid_properties.push('invalid value for "company_id", company_id cannot be nil.') end if @platform.nil? invalid_properties.push('invalid value for "platform", platform cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 311 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
206 207 208 209 210 211 212 213 |
# File 'lib/spartera_api_sdk/models/post_publications.rb', line 206 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @post_id.nil? return false if @company_id.nil? return false if @platform.nil? return false if @status.nil? true end |