Class: SparteraApiSdk::StorageEngines
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SparteraApiSdk::StorageEngines
- Defined in:
- lib/spartera_api_sdk/models/storage_engines.rb
Overview
Fact table of all the different storage engines we support
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#date_created ⇒ Object
Optional.
-
#engine_id ⇒ Object
Unique identifier.
-
#engine_type ⇒ Object
Required.
-
#integration_complete ⇒ Object
Optional.
-
#last_updated ⇒ Object
Optional.
-
#provider_id ⇒ Object
References cloud_providers.provider_id — Supported cloud platforms and database engines available for connections.
-
#service_name ⇒ Object
Required.
-
#test_func_complete ⇒ Object
Optional.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageEngines
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ StorageEngines
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SparteraApiSdk::StorageEngines` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SparteraApiSdk::StorageEngines`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'date_created') self.date_created = attributes[:'date_created'] end if attributes.key?(:'last_updated') self.last_updated = attributes[:'last_updated'] end if attributes.key?(:'engine_id') self.engine_id = attributes[:'engine_id'] end if attributes.key?(:'provider_id') self.provider_id = attributes[:'provider_id'] else self.provider_id = nil end if attributes.key?(:'service_name') self.service_name = attributes[:'service_name'] else self.service_name = nil end if attributes.key?(:'engine_type') self.engine_type = attributes[:'engine_type'] else self.engine_type = nil end if attributes.key?(:'integration_complete') self.integration_complete = attributes[:'integration_complete'] end if attributes.key?(:'test_func_complete') self.test_func_complete = attributes[:'test_func_complete'] end end |
Instance Attribute Details
#date_created ⇒ Object
Optional.
20 21 22 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 20 def date_created @date_created end |
#engine_id ⇒ Object
Unique identifier.
26 27 28 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 26 def engine_id @engine_id end |
#engine_type ⇒ Object
Required. One of: EDW, LLM, RDBMS, OBJ, API_MODEL, … (6 total).
35 36 37 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 35 def engine_type @engine_type end |
#integration_complete ⇒ Object
Optional.
38 39 40 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 38 def integration_complete @integration_complete end |
#last_updated ⇒ Object
Optional.
23 24 25 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 23 def last_updated @last_updated end |
#provider_id ⇒ Object
References cloud_providers.provider_id — Supported cloud platforms and database engines available for connections. See GET /cloud_providers for valid values. Required.
29 30 31 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 29 def provider_id @provider_id end |
#service_name ⇒ Object
Required.
32 33 34 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 32 def service_name @service_name end |
#test_func_complete ⇒ Object
Optional.
41 42 43 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 41 def test_func_complete @test_func_complete end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
80 81 82 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 80 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 85 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 66 def self.attribute_map { :'date_created' => :'date_created', :'last_updated' => :'last_updated', :'engine_id' => :'engine_id', :'provider_id' => :'provider_id', :'service_name' => :'service_name', :'engine_type' => :'engine_type', :'integration_complete' => :'integration_complete', :'test_func_complete' => :'test_func_complete' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 256 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 104 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 90 def self.openapi_types { :'date_created' => :'Time', :'last_updated' => :'Time', :'engine_id' => :'Integer', :'provider_id' => :'Integer', :'service_name' => :'String', :'engine_type' => :'String', :'integration_complete' => :'Boolean', :'test_func_complete' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 228 def ==(o) return true if self.equal?(o) self.class == o.class && date_created == o.date_created && last_updated == o.last_updated && engine_id == o.engine_id && provider_id == o.provider_id && service_name == o.service_name && engine_type == o.engine_type && integration_complete == o.integration_complete && test_func_complete == o.test_func_complete end |
#eql?(o) ⇒ Boolean
243 244 245 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 243 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
249 250 251 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 249 def hash [date_created, last_updated, engine_id, provider_id, service_name, engine_type, integration_complete, test_func_complete].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 166 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @provider_id.nil? invalid_properties.push('invalid value for "provider_id", provider_id cannot be nil.') end if @service_name.nil? invalid_properties.push('invalid value for "service_name", service_name cannot be nil.') end if @engine_type.nil? invalid_properties.push('invalid value for "engine_type", engine_type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 278 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
186 187 188 189 190 191 192 193 194 |
# File 'lib/spartera_api_sdk/models/storage_engines.rb', line 186 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @provider_id.nil? return false if @service_name.nil? return false if @engine_type.nil? engine_type_validator = EnumAttributeValidator.new('String', ["EDW", "LLM", "RDBMS", "OBJ", "API_MODEL", "EXTERNAL_API"]) return false unless engine_type_validator.valid?(@engine_type) true end |