Class: SparteraApiSdk::StorageEnginesApi
- Inherits:
-
Object
- Object
- SparteraApiSdk::StorageEnginesApi
- Defined in:
- lib/spartera_api_sdk/api/storage_engines_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_storage_engines_by_id(provider_id, engine_id, opts = {}) ⇒ GetStorageEnginesById200Response
Get single storage engine by ID.
-
#get_storage_engines_by_id_with_http_info(provider_id, engine_id, opts = {}) ⇒ Array<(GetStorageEnginesById200Response, Integer, Hash)>
Get single storage engine by ID.
-
#initialize(api_client = ApiClient.default) ⇒ StorageEnginesApi
constructor
A new instance of StorageEnginesApi.
-
#list_storage_engines(provider_id, opts = {}) ⇒ ListStorageEngines200Response
Get a list of all storage engines.
-
#list_storage_engines_with_http_info(provider_id, opts = {}) ⇒ Array<(ListStorageEngines200Response, Integer, Hash)>
Get a list of all storage engines.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ StorageEnginesApi
Returns a new instance of StorageEnginesApi.
19 20 21 |
# File 'lib/spartera_api_sdk/api/storage_engines_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/spartera_api_sdk/api/storage_engines_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_storage_engines_by_id(provider_id, engine_id, opts = {}) ⇒ GetStorageEnginesById200Response
Get single storage engine by ID
27 28 29 30 |
# File 'lib/spartera_api_sdk/api/storage_engines_api.rb', line 27 def get_storage_engines_by_id(provider_id, engine_id, opts = {}) data, _status_code, _headers = get_storage_engines_by_id_with_http_info(provider_id, engine_id, opts) data end |
#get_storage_engines_by_id_with_http_info(provider_id, engine_id, opts = {}) ⇒ Array<(GetStorageEnginesById200Response, Integer, Hash)>
Get single storage engine by ID
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/spartera_api_sdk/api/storage_engines_api.rb', line 37 def get_storage_engines_by_id_with_http_info(provider_id, engine_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: StorageEnginesApi.get_storage_engines_by_id ...' end # verify the required parameter 'provider_id' is set if @api_client.config.client_side_validation && provider_id.nil? fail ArgumentError, "Missing the required parameter 'provider_id' when calling StorageEnginesApi.get_storage_engines_by_id" end if @api_client.config.client_side_validation && provider_id.to_s.length > 255 fail ArgumentError, 'invalid value for "provider_id" when calling StorageEnginesApi.get_storage_engines_by_id, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && provider_id.to_s.length < 1 fail ArgumentError, 'invalid value for "provider_id" when calling StorageEnginesApi.get_storage_engines_by_id, the character length must be greater than or equal to 1.' end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if @api_client.config.client_side_validation && provider_id !~ pattern fail ArgumentError, "invalid value for 'provider_id' when calling StorageEnginesApi.get_storage_engines_by_id, must conform to the pattern #{pattern}." end # verify the required parameter 'engine_id' is set if @api_client.config.client_side_validation && engine_id.nil? fail ArgumentError, "Missing the required parameter 'engine_id' when calling StorageEnginesApi.get_storage_engines_by_id" end if @api_client.config.client_side_validation && engine_id.to_s.length > 255 fail ArgumentError, 'invalid value for "engine_id" when calling StorageEnginesApi.get_storage_engines_by_id, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && engine_id.to_s.length < 1 fail ArgumentError, 'invalid value for "engine_id" when calling StorageEnginesApi.get_storage_engines_by_id, the character length must be greater than or equal to 1.' end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if @api_client.config.client_side_validation && engine_id !~ pattern fail ArgumentError, "invalid value for 'engine_id' when calling StorageEnginesApi.get_storage_engines_by_id, must conform to the pattern #{pattern}." end # resource path local_var_path = '/cloud-providers/{provider_id}/storage-engines/{engine_id}'.sub('{' + 'provider_id' + '}', CGI.escape(provider_id.to_s)).sub('{' + 'engine_id' + '}', CGI.escape(engine_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetStorageEnginesById200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"StorageEnginesApi.get_storage_engines_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: StorageEnginesApi#get_storage_engines_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_storage_engines(provider_id, opts = {}) ⇒ ListStorageEngines200Response
Get a list of all storage engines
124 125 126 127 |
# File 'lib/spartera_api_sdk/api/storage_engines_api.rb', line 124 def list_storage_engines(provider_id, opts = {}) data, _status_code, _headers = list_storage_engines_with_http_info(provider_id, opts) data end |
#list_storage_engines_with_http_info(provider_id, opts = {}) ⇒ Array<(ListStorageEngines200Response, Integer, Hash)>
Get a list of all storage engines
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/spartera_api_sdk/api/storage_engines_api.rb', line 138 def list_storage_engines_with_http_info(provider_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: StorageEnginesApi.list_storage_engines ...' end # verify the required parameter 'provider_id' is set if @api_client.config.client_side_validation && provider_id.nil? fail ArgumentError, "Missing the required parameter 'provider_id' when calling StorageEnginesApi.list_storage_engines" end if @api_client.config.client_side_validation && provider_id.to_s.length > 255 fail ArgumentError, 'invalid value for "provider_id" when calling StorageEnginesApi.list_storage_engines, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && provider_id.to_s.length < 1 fail ArgumentError, 'invalid value for "provider_id" when calling StorageEnginesApi.list_storage_engines, the character length must be greater than or equal to 1.' end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if @api_client.config.client_side_validation && provider_id !~ pattern fail ArgumentError, "invalid value for 'provider_id' when calling StorageEnginesApi.list_storage_engines, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling StorageEnginesApi.list_storage_engines, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling StorageEnginesApi.list_storage_engines, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling StorageEnginesApi.list_storage_engines, must be greater than or equal to 1.' end allowable_values = ["asc", "desc"] if @api_client.config.client_side_validation && opts[:'sort_order'] && !allowable_values.include?(opts[:'sort_order']) fail ArgumentError, "invalid value for \"sort_order\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length > 255 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling StorageEnginesApi.list_storage_engines, the character length must be smaller than or equal to 255.' end if @api_client.config.client_side_validation && !opts[:'search'].nil? && opts[:'search'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"search"]" when calling StorageEnginesApi.list_storage_engines, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/cloud-providers/{provider_id}/storage-engines'.sub('{' + 'provider_id' + '}', CGI.escape(provider_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? query_params[:'sort_order'] = opts[:'sort_order'] if !opts[:'sort_order'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListStorageEngines200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"StorageEnginesApi.list_storage_engines", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: StorageEnginesApi#list_storage_engines\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |